/* wizard-source.c generated by valac 0.22.0.39-4730, the Vala compiler
 * generated from wizard-source.vala, do not modify */

/* This file is part of GNOME Boxes. License: LGPLv2+*/

#include <glib.h>
#include <glib-object.h>
#include <gtk/gtk.h>
#include <stdlib.h>
#include <string.h>
#include <glib/gi18n-lib.h>
#include <gio/gio.h>
#include <libvirt-gconfig/libvirt-gconfig.h>
#include <libcommon.h>
#include <osinfo/osinfo.h>
#include <pango/pango.h>
#include <float.h>
#include <math.h>
#include <clutter/clutter.h>
#include <clutter-gtk/clutter-gtk.h>


#define BOXES_TYPE_SOURCE_PAGE (boxes_source_page_get_type ())

#define BOXES_TYPE_WIZARD_SCROLLED (boxes_wizard_scrolled_get_type ())
#define BOXES_WIZARD_SCROLLED(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_WIZARD_SCROLLED, BoxesWizardScrolled))
#define BOXES_WIZARD_SCROLLED_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_WIZARD_SCROLLED, BoxesWizardScrolledClass))
#define BOXES_IS_WIZARD_SCROLLED(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_WIZARD_SCROLLED))
#define BOXES_IS_WIZARD_SCROLLED_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_WIZARD_SCROLLED))
#define BOXES_WIZARD_SCROLLED_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_WIZARD_SCROLLED, BoxesWizardScrolledClass))

typedef struct _BoxesWizardScrolled BoxesWizardScrolled;
typedef struct _BoxesWizardScrolledClass BoxesWizardScrolledClass;
typedef struct _BoxesWizardScrolledPrivate BoxesWizardScrolledPrivate;
#define _g_list_free0(var) ((var == NULL) ? NULL : (var = (g_list_free (var), NULL)))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

#define BOXES_TYPE_WIZARD_SOURCE (boxes_wizard_source_get_type ())
#define BOXES_WIZARD_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_WIZARD_SOURCE, BoxesWizardSource))
#define BOXES_WIZARD_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_WIZARD_SOURCE, BoxesWizardSourceClass))
#define BOXES_IS_WIZARD_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_WIZARD_SOURCE))
#define BOXES_IS_WIZARD_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_WIZARD_SOURCE))
#define BOXES_WIZARD_SOURCE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_WIZARD_SOURCE, BoxesWizardSourceClass))

typedef struct _BoxesWizardSource BoxesWizardSource;
typedef struct _BoxesWizardSourceClass BoxesWizardSourceClass;
typedef struct _BoxesWizardSourcePrivate BoxesWizardSourcePrivate;

#define BOXES_TYPE_INSTALLER_MEDIA (boxes_installer_media_get_type ())
#define BOXES_INSTALLER_MEDIA(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_INSTALLER_MEDIA, BoxesInstallerMedia))
#define BOXES_INSTALLER_MEDIA_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_INSTALLER_MEDIA, BoxesInstallerMediaClass))
#define BOXES_IS_INSTALLER_MEDIA(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_INSTALLER_MEDIA))
#define BOXES_IS_INSTALLER_MEDIA_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_INSTALLER_MEDIA))
#define BOXES_INSTALLER_MEDIA_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_INSTALLER_MEDIA, BoxesInstallerMediaClass))

typedef struct _BoxesInstallerMedia BoxesInstallerMedia;
typedef struct _BoxesInstallerMediaClass BoxesInstallerMediaClass;

#define BOXES_TYPE_MEDIA_MANAGER (boxes_media_manager_get_type ())
#define BOXES_MEDIA_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_MEDIA_MANAGER, BoxesMediaManager))
#define BOXES_MEDIA_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_MEDIA_MANAGER, BoxesMediaManagerClass))
#define BOXES_IS_MEDIA_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_MEDIA_MANAGER))
#define BOXES_IS_MEDIA_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_MEDIA_MANAGER))
#define BOXES_MEDIA_MANAGER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_MEDIA_MANAGER, BoxesMediaManagerClass))

typedef struct _BoxesMediaManager BoxesMediaManager;
typedef struct _BoxesMediaManagerClass BoxesMediaManagerClass;
#define _g_free0(var) (var = (g_free (var), NULL))
typedef struct _BoxesInstallerMediaPrivate BoxesInstallerMediaPrivate;

#define BOXES_TYPE_VM_CREATOR (boxes_vm_creator_get_type ())
#define BOXES_VM_CREATOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_VM_CREATOR, BoxesVMCreator))
#define BOXES_VM_CREATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_VM_CREATOR, BoxesVMCreatorClass))
#define BOXES_IS_VM_CREATOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_VM_CREATOR))
#define BOXES_IS_VM_CREATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_VM_CREATOR))
#define BOXES_VM_CREATOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_VM_CREATOR, BoxesVMCreatorClass))

typedef struct _BoxesVMCreator BoxesVMCreator;
typedef struct _BoxesVMCreatorClass BoxesVMCreatorClass;
#define __g_list_free__g_object_unref0_0(var) ((var == NULL) ? NULL : (var = (_g_list_free__g_object_unref0_ (var), NULL)))
typedef struct _BoxesWizardSourceAddMediaEntriesData BoxesWizardSourceAddMediaEntriesData;
typedef struct _Block72Data Block72Data;
typedef struct _Block73Data Block73Data;
typedef struct _Block74Data Block74Data;

#define BOXES_TYPE_UI (boxes_ui_get_type ())
#define BOXES_UI(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_UI, BoxesUI))
#define BOXES_UI_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_UI, BoxesUIClass))
#define BOXES_IS_UI(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_UI))
#define BOXES_IS_UI_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_UI))
#define BOXES_UI_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_UI, BoxesUIClass))

typedef struct _BoxesUI BoxesUI;
typedef struct _BoxesUIClass BoxesUIClass;

#define BOXES_TYPE_APP (boxes_app_get_type ())
#define BOXES_APP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_APP, BoxesApp))
#define BOXES_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_APP, BoxesAppClass))
#define BOXES_IS_APP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_APP))
#define BOXES_IS_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_APP))
#define BOXES_APP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_APP, BoxesAppClass))

typedef struct _BoxesApp BoxesApp;
typedef struct _BoxesAppClass BoxesAppClass;
typedef struct _BoxesUIPrivate BoxesUIPrivate;
typedef struct _BoxesAppPrivate BoxesAppPrivate;

#define BOXES_TYPE_CLUTTER_WIDGET (boxes_clutter_widget_get_type ())
#define BOXES_CLUTTER_WIDGET(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_CLUTTER_WIDGET, BoxesClutterWidget))
#define BOXES_CLUTTER_WIDGET_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_CLUTTER_WIDGET, BoxesClutterWidgetClass))
#define BOXES_IS_CLUTTER_WIDGET(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_CLUTTER_WIDGET))
#define BOXES_IS_CLUTTER_WIDGET_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_CLUTTER_WIDGET))
#define BOXES_CLUTTER_WIDGET_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_CLUTTER_WIDGET, BoxesClutterWidgetClass))

typedef struct _BoxesClutterWidget BoxesClutterWidget;
typedef struct _BoxesClutterWidgetClass BoxesClutterWidgetClass;

#define BOXES_TYPE_COLLECTION_ITEM (boxes_collection_item_get_type ())
#define BOXES_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItem))
#define BOXES_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))
#define BOXES_IS_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_IS_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_COLLECTION_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))

typedef struct _BoxesCollectionItem BoxesCollectionItem;
typedef struct _BoxesCollectionItemClass BoxesCollectionItemClass;

#define BOXES_TYPE_SEARCHBAR (boxes_searchbar_get_type ())
#define BOXES_SEARCHBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SEARCHBAR, BoxesSearchbar))
#define BOXES_SEARCHBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SEARCHBAR, BoxesSearchbarClass))
#define BOXES_IS_SEARCHBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SEARCHBAR))
#define BOXES_IS_SEARCHBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SEARCHBAR))
#define BOXES_SEARCHBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SEARCHBAR, BoxesSearchbarClass))

typedef struct _BoxesSearchbar BoxesSearchbar;
typedef struct _BoxesSearchbarClass BoxesSearchbarClass;

#define BOXES_TYPE_TOPBAR (boxes_topbar_get_type ())
#define BOXES_TOPBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_TOPBAR, BoxesTopbar))
#define BOXES_TOPBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_TOPBAR, BoxesTopbarClass))
#define BOXES_IS_TOPBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_TOPBAR))
#define BOXES_IS_TOPBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_TOPBAR))
#define BOXES_TOPBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_TOPBAR, BoxesTopbarClass))

typedef struct _BoxesTopbar BoxesTopbar;
typedef struct _BoxesTopbarClass BoxesTopbarClass;

#define BOXES_TYPE_NOTIFICATIONBAR (boxes_notificationbar_get_type ())
#define BOXES_NOTIFICATIONBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbar))
#define BOXES_NOTIFICATIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarClass))
#define BOXES_IS_NOTIFICATIONBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_NOTIFICATIONBAR))
#define BOXES_IS_NOTIFICATIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_NOTIFICATIONBAR))
#define BOXES_NOTIFICATIONBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarClass))

typedef struct _BoxesNotificationbar BoxesNotificationbar;
typedef struct _BoxesNotificationbarClass BoxesNotificationbarClass;

#define BOXES_TYPE_REVEALER (boxes_revealer_get_type ())
#define BOXES_REVEALER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_REVEALER, BoxesRevealer))
#define BOXES_REVEALER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_REVEALER, BoxesRevealerClass))
#define BOXES_IS_REVEALER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_REVEALER))
#define BOXES_IS_REVEALER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_REVEALER))
#define BOXES_REVEALER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_REVEALER, BoxesRevealerClass))

typedef struct _BoxesRevealer BoxesRevealer;
typedef struct _BoxesRevealerClass BoxesRevealerClass;

#define BOXES_TYPE_SIDEBAR (boxes_sidebar_get_type ())
#define BOXES_SIDEBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SIDEBAR, BoxesSidebar))
#define BOXES_SIDEBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SIDEBAR, BoxesSidebarClass))
#define BOXES_IS_SIDEBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SIDEBAR))
#define BOXES_IS_SIDEBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SIDEBAR))
#define BOXES_SIDEBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SIDEBAR, BoxesSidebarClass))

typedef struct _BoxesSidebar BoxesSidebar;
typedef struct _BoxesSidebarClass BoxesSidebarClass;

#define BOXES_TYPE_SELECTIONBAR (boxes_selectionbar_get_type ())
#define BOXES_SELECTIONBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbar))
#define BOXES_SELECTIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbarClass))
#define BOXES_IS_SELECTIONBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SELECTIONBAR))
#define BOXES_IS_SELECTIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SELECTIONBAR))
#define BOXES_SELECTIONBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbarClass))

typedef struct _BoxesSelectionbar BoxesSelectionbar;
typedef struct _BoxesSelectionbarClass BoxesSelectionbarClass;

#define BOXES_TYPE_WIZARD (boxes_wizard_get_type ())
#define BOXES_WIZARD(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_WIZARD, BoxesWizard))
#define BOXES_WIZARD_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_WIZARD, BoxesWizardClass))
#define BOXES_IS_WIZARD(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_WIZARD))
#define BOXES_IS_WIZARD_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_WIZARD))
#define BOXES_WIZARD_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_WIZARD, BoxesWizardClass))

typedef struct _BoxesWizard BoxesWizard;
typedef struct _BoxesWizardClass BoxesWizardClass;

#define BOXES_TYPE_PROPERTIES (boxes_properties_get_type ())
#define BOXES_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_PROPERTIES, BoxesProperties))
#define BOXES_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_PROPERTIES, BoxesPropertiesClass))
#define BOXES_IS_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_PROPERTIES))
#define BOXES_IS_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_PROPERTIES))
#define BOXES_PROPERTIES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_PROPERTIES, BoxesPropertiesClass))

typedef struct _BoxesProperties BoxesProperties;
typedef struct _BoxesPropertiesClass BoxesPropertiesClass;

#define BOXES_TYPE_DISPLAY_PAGE (boxes_display_page_get_type ())
#define BOXES_DISPLAY_PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPage))
#define BOXES_DISPLAY_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPageClass))
#define BOXES_IS_DISPLAY_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_DISPLAY_PAGE))
#define BOXES_IS_DISPLAY_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_DISPLAY_PAGE))
#define BOXES_DISPLAY_PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPageClass))

typedef struct _BoxesDisplayPage BoxesDisplayPage;
typedef struct _BoxesDisplayPageClass BoxesDisplayPageClass;

#define BOXES_TYPE_EMPTY_BOXES (boxes_empty_boxes_get_type ())
#define BOXES_EMPTY_BOXES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxes))
#define BOXES_EMPTY_BOXES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxesClass))
#define BOXES_IS_EMPTY_BOXES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_EMPTY_BOXES))
#define BOXES_IS_EMPTY_BOXES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_EMPTY_BOXES))
#define BOXES_EMPTY_BOXES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxesClass))

typedef struct _BoxesEmptyBoxes BoxesEmptyBoxes;
typedef struct _BoxesEmptyBoxesClass BoxesEmptyBoxesClass;

#define BOXES_TYPE_COLLECTION (boxes_collection_get_type ())
#define BOXES_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION, BoxesCollection))
#define BOXES_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION, BoxesCollectionClass))
#define BOXES_IS_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION))
#define BOXES_IS_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION))
#define BOXES_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION, BoxesCollectionClass))

typedef struct _BoxesCollection BoxesCollection;
typedef struct _BoxesCollectionClass BoxesCollectionClass;

#define BOXES_TYPE_COLLECTION_FILTER (boxes_collection_filter_get_type ())
#define BOXES_COLLECTION_FILTER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_FILTER, BoxesCollectionFilter))
#define BOXES_COLLECTION_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_FILTER, BoxesCollectionFilterClass))
#define BOXES_IS_COLLECTION_FILTER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_FILTER))
#define BOXES_IS_COLLECTION_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_FILTER))
#define BOXES_COLLECTION_FILTER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_FILTER, BoxesCollectionFilterClass))

typedef struct _BoxesCollectionFilter BoxesCollectionFilter;
typedef struct _BoxesCollectionFilterClass BoxesCollectionFilterClass;

#define BOXES_TYPE_COLLECTION_VIEW (boxes_collection_view_get_type ())
#define BOXES_COLLECTION_VIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionView))
#define BOXES_COLLECTION_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionViewClass))
#define BOXES_IS_COLLECTION_VIEW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_VIEW))
#define BOXES_IS_COLLECTION_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_VIEW))
#define BOXES_COLLECTION_VIEW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionViewClass))

typedef struct _BoxesCollectionView BoxesCollectionView;
typedef struct _BoxesCollectionViewClass BoxesCollectionViewClass;
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))

typedef enum  {
	BOXES_SOURCE_PAGE_MAIN,
	BOXES_SOURCE_PAGE_URL,
	BOXES_SOURCE_PAGE_LAST
} BoxesSourcePage;

typedef gboolean (*ClickedFunc) (void* user_data);
struct _BoxesWizardScrolled {
	GtkScrolledWindow parent_instance;
	BoxesWizardScrolledPrivate * priv;
};

struct _BoxesWizardScrolledClass {
	GtkScrolledWindowClass parent_class;
};

struct _BoxesWizardScrolledPrivate {
	gint num_visible;
};

struct _BoxesWizardSource {
	GObject parent_instance;
	BoxesWizardSourcePrivate * priv;
	GtkEntry* url_entry;
};

struct _BoxesWizardSourceClass {
	GObjectClass parent_class;
};

struct _BoxesWizardSourcePrivate {
	GtkWidget* _selected;
	BoxesSourcePage _page;
	BoxesInstallerMedia* _install_media;
	GtkBox* main_vbox;
	GtkBox* media_vbox;
	GtkScrolledWindow* media_scrolled;
	GtkNotebook* notebook;
	GtkLabel* url_label;
	GtkImage* url_image;
	BoxesMediaManager* media_manager;
};

struct _BoxesInstallerMedia {
	GObject parent_instance;
	BoxesInstallerMediaPrivate * priv;
	OsinfoOs* os;
	OsinfoResources* resources;
	OsinfoMedia* os_media;
	gchar* label;
	gchar* device_file;
	gchar* mount_point;
	gboolean from_image;
};

struct _BoxesInstallerMediaClass {
	GObjectClass parent_class;
	void (*set_direct_boot_params) (BoxesInstallerMedia* self, GVirConfigDomainOs* os);
	void (*prepare) (BoxesInstallerMedia* self, BoxesActivityProgress* progress, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*prepare_finish) (BoxesInstallerMedia* self, GAsyncResult* _res_);
	void (*prepare_for_installation) (BoxesInstallerMedia* self, const gchar* vm_name, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*prepare_for_installation_finish) (BoxesInstallerMedia* self, GAsyncResult* _res_, GError** error);
	void (*prepare_to_continue_installation) (BoxesInstallerMedia* self, const gchar* vm_name);
	void (*clean_up) (BoxesInstallerMedia* self);
	void (*clean_up_preparation_cache) (BoxesInstallerMedia* self);
	void (*setup_domain_config) (BoxesInstallerMedia* self, GVirConfigDomain* domain);
	void (*setup_post_install_domain_config) (BoxesInstallerMedia* self, GVirConfigDomain* domain);
	void (*populate_setup_vbox) (BoxesInstallerMedia* self, GtkBox* setup_vbox);
	GList* (*get_vm_properties) (BoxesInstallerMedia* self);
	BoxesVMCreator* (*get_vm_creator) (BoxesInstallerMedia* self);
	OsinfoDeviceList* (*get_supported_devices) (BoxesInstallerMedia* self);
	guint64 (*get_installed_size) (BoxesInstallerMedia* self);
	gboolean (*get_need_user_input_for_vm_creation) (BoxesInstallerMedia* self);
	gboolean (*get_ready_to_create) (BoxesInstallerMedia* self);
	gboolean (*get_live) (BoxesInstallerMedia* self);
	gchar* (*get_architecture) (BoxesInstallerMedia* self);
};

struct _BoxesWizardSourceAddMediaEntriesData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesWizardSource* self;
	GList* medias;
	BoxesMediaManager* _tmp0_;
	GList* _tmp1_;
	GtkBox* _tmp2_;
	GList* _tmp3_;
	GList* child_collection;
	GList* child_it;
	GtkWidget* child;
	gchar* child_media;
	GtkWidget* _tmp4_;
	gconstpointer _tmp5_;
	gchar* _tmp6_;
	const gchar* _tmp7_;
	gboolean obsolete;
	GList* _tmp8_;
	GList* media_collection;
	GList* media_it;
	BoxesInstallerMedia* _tmp9_;
	BoxesInstallerMedia* media;
	const gchar* _tmp10_;
	BoxesInstallerMedia* _tmp11_;
	const gchar* _tmp12_;
	gboolean _tmp13_;
	GtkBox* _tmp14_;
	GtkWidget* _tmp15_;
	GList* _tmp16_;
	GList* _vala1_media_collection;
	GList* _vala1_media_it;
	BoxesInstallerMedia* _tmp17_;
	BoxesInstallerMedia* _vala1_media;
	gboolean nouveau;
	GtkBox* _tmp18_;
	GList* _tmp19_;
	GList* _vala1_child_collection;
	GList* _vala1_child_it;
	GtkWidget* _vala1_child;
	gchar* _vala1_child_media;
	GtkWidget* _tmp20_;
	gconstpointer _tmp21_;
	gchar* _tmp22_;
	gboolean _tmp23_;
	const gchar* _tmp24_;
	const gchar* _tmp25_;
	BoxesInstallerMedia* _tmp26_;
	const gchar* _tmp27_;
	gboolean _tmp28_;
	gboolean _tmp29_;
	BoxesInstallerMedia* _tmp30_;
	GtkBox* _tmp31_;
	GList* _tmp32_;
	GList* _tmp33_;
	guint _tmp34_;
	gboolean _tmp35_;
	GtkScrolledWindow* _tmp36_;
};

struct _Block72Data {
	int _ref_count_;
	BoxesWizardSource * self;
	BoxesInstallerMedia* media;
};

struct _Block73Data {
	int _ref_count_;
	BoxesWizardSource * self;
	ClickedFunc clicked;
	gpointer clicked_target;
	GDestroyNotify clicked_target_destroy_notify;
};

struct _Block74Data {
	int _ref_count_;
	Block73Data * _data73_;
	GtkButton* button;
};

struct _BoxesUI {
	GObject parent_instance;
	BoxesUIPrivate * priv;
};

struct _BoxesUIClass {
	GObjectClass parent_class;
	void (*ui_state_changed) (BoxesUI* self);
	ClutterActor* (*get_actor) (BoxesUI* self);
};

struct _BoxesApp {
	BoxesUI parent_instance;
	BoxesAppPrivate * priv;
	GtkApplicationWindow* window;
	GtkNotebook* notebook;
	BoxesClutterWidget* embed;
	ClutterStage* stage;
	ClutterBinLayout* stage_bin;
	ClutterActor* overlay_bin_actor;
	ClutterBinLayout* overlay_bin;
	BoxesCollectionItem* current_item;
	BoxesSearchbar* searchbar;
	BoxesTopbar* topbar;
	BoxesNotificationbar* notificationbar;
	BoxesRevealer* sidebar_revealer;
	BoxesRevealer* searchbar_revealer;
	BoxesSidebar* sidebar;
	BoxesSelectionbar* selectionbar;
	guint duration;
	GSettings* settings;
	BoxesWizard* wizard;
	BoxesProperties* properties;
	BoxesDisplayPage* display_page;
	BoxesEmptyBoxes* empty_boxes;
	BoxesCollection* collection;
	BoxesCollectionFilter* filter;
	BoxesCollectionView* view;
};

struct _BoxesAppClass {
	BoxesUIClass parent_class;
};


static gpointer boxes_wizard_scrolled_parent_class = NULL;
static gpointer boxes_wizard_source_parent_class = NULL;
extern BoxesApp* boxes_app_app;

GType boxes_source_page_get_type (void) G_GNUC_CONST;
GType boxes_wizard_scrolled_get_type (void) G_GNUC_CONST;
#define BOXES_WIZARD_SCROLLED_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_WIZARD_SCROLLED, BoxesWizardScrolledPrivate))
enum  {
	BOXES_WIZARD_SCROLLED_DUMMY_PROPERTY
};
BoxesWizardScrolled* boxes_wizard_scrolled_new (gint num_visible);
BoxesWizardScrolled* boxes_wizard_scrolled_construct (GType object_type, gint num_visible);
static void __lambda181_ (BoxesWizardScrolled* self);
static void ___lambda181__gtk_widget_show (GtkWidget* _sender, gpointer self);
static void __lambda182_ (BoxesWizardScrolled* self);
static void ___lambda182__gtk_widget_hide (GtkWidget* _sender, gpointer self);
static void boxes_wizard_scrolled_real_get_preferred_height (GtkWidget* base, gint* minimum_height, gint* natural_height);
static void boxes_wizard_scrolled_finalize (GObject* obj);
GType boxes_wizard_source_get_type (void) G_GNUC_CONST;
GType boxes_installer_media_get_type (void) G_GNUC_CONST;
GType boxes_media_manager_get_type (void) G_GNUC_CONST;
#define BOXES_WIZARD_SOURCE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_WIZARD_SOURCE, BoxesWizardSourcePrivate))
enum  {
	BOXES_WIZARD_SOURCE_DUMMY_PROPERTY,
	BOXES_WIZARD_SOURCE_WIDGET,
	BOXES_WIZARD_SOURCE_SELECTED,
	BOXES_WIZARD_SOURCE_PAGE,
	BOXES_WIZARD_SOURCE_URI,
	BOXES_WIZARD_SOURCE_INSTALL_MEDIA
};
BoxesWizardSource* boxes_wizard_source_new (BoxesMediaManager* media_manager);
BoxesWizardSource* boxes_wizard_source_construct (GType object_type, BoxesMediaManager* media_manager);
static GtkBox* boxes_wizard_source_add_entry (BoxesWizardSource* self, GtkBox* box, ClickedFunc clicked, void* clicked_target, GDestroyNotify clicked_target_destroy_notify, gint h_margin, gint v_margin, const gchar* media);
static gboolean __lambda185_ (BoxesWizardSource* self);
void boxes_wizard_source_set_page (BoxesWizardSource* self, BoxesSourcePage value);
static gboolean ___lambda185__clicked_func (gpointer self);
static gboolean boxes_wizard_source_launch_file_selection_dialog (BoxesWizardSource* self);
static gboolean _boxes_wizard_source_launch_file_selection_dialog_clicked_func (gpointer self);
static gboolean __lambda187_ (BoxesWizardSource* self);
void boxes_wizard_source_set_selected (BoxesWizardSource* self, GtkWidget* value);
static gboolean ___lambda187__clicked_func (gpointer self);
static void boxes_wizard_source_add_media_entries (BoxesWizardSource* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void boxes_wizard_source_add_media_entries_finish (BoxesWizardSource* self, GAsyncResult* _res_);
void boxes_wizard_source_update_url_page (BoxesWizardSource* self, const gchar* title, const gchar* text, const gchar* icon_name);
static void boxes_wizard_source_add_media_entries_data_free (gpointer _data);
static gboolean boxes_wizard_source_add_media_entries_co (BoxesWizardSourceAddMediaEntriesData* _data_);
void boxes_media_manager_list_installer_medias (BoxesMediaManager* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
GList* boxes_media_manager_list_installer_medias_finish (BoxesMediaManager* self, GAsyncResult* _res_);
static void boxes_wizard_source_add_media_entries_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
gpointer boxes_vm_creator_ref (gpointer instance);
void boxes_vm_creator_unref (gpointer instance);
GParamSpec* boxes_param_spec_vm_creator (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void boxes_value_set_vm_creator (GValue* value, gpointer v_object);
void boxes_value_take_vm_creator (GValue* value, gpointer v_object);
gpointer boxes_value_get_vm_creator (const GValue* value);
GType boxes_vm_creator_get_type (void) G_GNUC_CONST;
static void boxes_wizard_source_add_media_entry (BoxesWizardSource* self, BoxesInstallerMedia* media);
static void _g_object_unref0_ (gpointer var);
static void _g_list_free__g_object_unref0_ (GList* self);
static Block72Data* block72_data_ref (Block72Data* _data72_);
static void block72_data_unref (void * _userdata_);
static gboolean __lambda186_ (Block72Data* _data72_);
static void boxes_wizard_source_on_media_selected (BoxesWizardSource* self, BoxesInstallerMedia* media);
static gboolean ___lambda186__clicked_func (gpointer self);
void boxes_downloader_fetch_os_logo (GtkImage* image, OsinfoOs* os, gint size, GAsyncReadyCallback _callback_, gpointer _user_data_);
void boxes_downloader_fetch_os_logo_finish (GAsyncResult* _res_);
static Block73Data* block73_data_ref (Block73Data* _data73_);
static void block73_data_unref (void * _userdata_);
static Block74Data* block74_data_ref (Block74Data* _data74_);
static void block74_data_unref (void * _userdata_);
static void ___lambda183_ (Block74Data* _data74_);
static void ____lambda183__gtk_button_clicked (GtkButton* _sender, gpointer self);
void boxes_draw_as_css_box (GtkWidget* widget);
GType boxes_ui_get_type (void) G_GNUC_CONST;
GType boxes_app_get_type (void) G_GNUC_CONST;
GType boxes_clutter_widget_get_type (void) G_GNUC_CONST;
GType boxes_collection_item_get_type (void) G_GNUC_CONST;
GType boxes_searchbar_get_type (void) G_GNUC_CONST;
GType boxes_topbar_get_type (void) G_GNUC_CONST;
GType boxes_notificationbar_get_type (void) G_GNUC_CONST;
GType boxes_revealer_get_type (void) G_GNUC_CONST;
GType boxes_sidebar_get_type (void) G_GNUC_CONST;
GType boxes_selectionbar_get_type (void) G_GNUC_CONST;
GType boxes_wizard_get_type (void) G_GNUC_CONST;
GType boxes_properties_get_type (void) G_GNUC_CONST;
GType boxes_display_page_get_type (void) G_GNUC_CONST;
GType boxes_empty_boxes_get_type (void) G_GNUC_CONST;
GType boxes_collection_get_type (void) G_GNUC_CONST;
GType boxes_collection_filter_get_type (void) G_GNUC_CONST;
GType boxes_collection_view_get_type (void) G_GNUC_CONST;
void boxes_wizard_source_set_uri (BoxesWizardSource* self, const gchar* value);
static void boxes_wizard_source_set_install_media (BoxesWizardSource* self, BoxesInstallerMedia* value);
BoxesInstallerMedia* boxes_media_manager_create_installer_media_from_media (BoxesMediaManager* self, BoxesInstallerMedia* media, GError** error);
GtkWidget* boxes_wizard_source_get_widget (BoxesWizardSource* self);
GtkWidget* boxes_wizard_source_get_selected (BoxesWizardSource* self);
BoxesSourcePage boxes_wizard_source_get_page (BoxesWizardSource* self);
const gchar* boxes_wizard_source_get_uri (BoxesWizardSource* self);
BoxesInstallerMedia* boxes_wizard_source_get_install_media (BoxesWizardSource* self);
static void boxes_wizard_source_finalize (GObject* obj);
static void _vala_boxes_wizard_source_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_boxes_wizard_source_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);

extern const gchar* BOXES_INSTALLED_MEDIA_supported_extensions[16];

GType boxes_source_page_get_type (void) {
	static volatile gsize boxes_source_page_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_source_page_type_id__volatile)) {
		static const GEnumValue values[] = {{BOXES_SOURCE_PAGE_MAIN, "BOXES_SOURCE_PAGE_MAIN", "main"}, {BOXES_SOURCE_PAGE_URL, "BOXES_SOURCE_PAGE_URL", "url"}, {BOXES_SOURCE_PAGE_LAST, "BOXES_SOURCE_PAGE_LAST", "last"}, {0, NULL, NULL}};
		GType boxes_source_page_type_id;
		boxes_source_page_type_id = g_enum_register_static ("BoxesSourcePage", values);
		g_once_init_leave (&boxes_source_page_type_id__volatile, boxes_source_page_type_id);
	}
	return boxes_source_page_type_id__volatile;
}


static void __lambda181_ (BoxesWizardScrolled* self) {
	GtkStyleContext* _tmp0_ = NULL;
#line 21 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp0_ = gtk_widget_get_style_context ((GtkWidget*) self);
#line 21 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	gtk_style_context_add_class (_tmp0_, "boxes-menu-scrolled");
#line 22 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	gtk_widget_reset_style ((GtkWidget*) self);
#line 589 "wizard-source.c"
}


static void ___lambda181__gtk_widget_show (GtkWidget* _sender, gpointer self) {
#line 20 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	__lambda181_ (self);
#line 596 "wizard-source.c"
}


static void __lambda182_ (BoxesWizardScrolled* self) {
	GtkStyleContext* _tmp0_ = NULL;
#line 25 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp0_ = gtk_widget_get_style_context ((GtkWidget*) self);
#line 25 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	gtk_style_context_remove_class (_tmp0_, "boxes-menu-scrolled");
#line 26 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	gtk_widget_reset_style ((GtkWidget*) self);
#line 608 "wizard-source.c"
}


static void ___lambda182__gtk_widget_hide (GtkWidget* _sender, gpointer self) {
#line 24 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	__lambda182_ (self);
#line 615 "wizard-source.c"
}


BoxesWizardScrolled* boxes_wizard_scrolled_construct (GType object_type, gint num_visible) {
	BoxesWizardScrolled * self = NULL;
	gint _tmp0_ = 0;
	GtkStyleContext* _tmp1_ = NULL;
	GtkWidget* _tmp2_ = NULL;
	GtkWidget* _tmp3_ = NULL;
#line 16 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	self = (BoxesWizardScrolled*) g_object_new (object_type, NULL);
#line 17 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp0_ = num_visible;
#line 17 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	self->priv->num_visible = _tmp0_;
#line 18 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp1_ = gtk_widget_get_style_context ((GtkWidget*) self);
#line 18 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	gtk_style_context_add_class (_tmp1_, "boxes-menu-scrolled");
#line 19 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	gtk_scrolled_window_set_policy ((GtkScrolledWindow*) self, GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
#line 20 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp2_ = gtk_scrolled_window_get_vscrollbar ((GtkScrolledWindow*) self);
#line 20 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	g_signal_connect_object (_tmp2_, "show", (GCallback) ___lambda181__gtk_widget_show, self, 0);
#line 24 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp3_ = gtk_scrolled_window_get_vscrollbar ((GtkScrolledWindow*) self);
#line 24 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	g_signal_connect_object (_tmp3_, "hide", (GCallback) ___lambda182__gtk_widget_hide, self, 0);
#line 16 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	return self;
#line 647 "wizard-source.c"
}


BoxesWizardScrolled* boxes_wizard_scrolled_new (gint num_visible) {
#line 16 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	return boxes_wizard_scrolled_construct (BOXES_TYPE_WIZARD_SCROLLED, num_visible);
#line 654 "wizard-source.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 32 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	return self ? g_object_ref (self) : NULL;
#line 661 "wizard-source.c"
}


static void boxes_wizard_scrolled_real_get_preferred_height (GtkWidget* base, gint* minimum_height, gint* natural_height) {
	BoxesWizardScrolled * self;
	gint _vala_minimum_height = 0;
	gint _vala_natural_height = 0;
	gint _tmp0_ = 0;
	gint _tmp1_ = 0;
	GtkViewport* viewport = NULL;
	GtkWidget* _tmp2_ = NULL;
	GtkViewport* _tmp3_ = NULL;
	GtkBox* box = NULL;
	GtkViewport* _tmp4_ = NULL;
	GtkWidget* _tmp5_ = NULL;
	GtkBox* _tmp6_ = NULL;
	gint height = 0;
	gint i = 0;
	GtkBox* _tmp7_ = NULL;
	GList* _tmp8_ = NULL;
	gint _tmp18_ = 0;
	gint _tmp19_ = 0;
	gint _tmp20_ = 0;
	gint _tmp21_ = 0;
	gint _tmp22_ = 0;
	gint _tmp23_ = 0;
#line 30 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	self = (BoxesWizardScrolled*) base;
#line 31 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	GTK_WIDGET_CLASS (boxes_wizard_scrolled_parent_class)->get_preferred_height ((GtkWidget*) G_TYPE_CHECK_INSTANCE_CAST (self, GTK_TYPE_SCROLLED_WINDOW, GtkScrolledWindow), &_tmp0_, &_tmp1_);
#line 31 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_vala_minimum_height = _tmp0_;
#line 31 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_vala_natural_height = _tmp1_;
#line 32 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp2_ = gtk_bin_get_child ((GtkBin*) self);
#line 32 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp3_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp2_, GTK_TYPE_VIEWPORT) ? ((GtkViewport*) _tmp2_) : NULL);
#line 32 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	viewport = _tmp3_;
#line 33 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp4_ = viewport;
#line 33 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp5_ = gtk_bin_get_child ((GtkBin*) _tmp4_);
#line 33 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp6_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp5_, GTK_TYPE_BOX) ? ((GtkBox*) _tmp5_) : NULL);
#line 33 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	box = _tmp6_;
#line 35 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	height = 0;
#line 36 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	i = 0;
#line 37 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp7_ = box;
#line 37 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp8_ = gtk_container_get_children ((GtkContainer*) _tmp7_);
#line 718 "wizard-source.c"
	{
		GList* w_collection = NULL;
		GList* w_it = NULL;
#line 37 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		w_collection = _tmp8_;
#line 37 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		for (w_it = w_collection; w_it != NULL; w_it = w_it->next) {
#line 726 "wizard-source.c"
			GtkWidget* w = NULL;
#line 37 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
			w = (GtkWidget*) w_it->data;
#line 730 "wizard-source.c"
			{
				GtkWidget* _tmp9_ = NULL;
				gboolean _tmp10_ = FALSE;
				gint child_height = 0;
				GtkWidget* _tmp11_ = NULL;
				gint _tmp12_ = 0;
				gint _tmp13_ = 0;
				gint _tmp14_ = 0;
				gint _tmp15_ = 0;
				gint _tmp16_ = 0;
				gint _tmp17_ = 0;
#line 38 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
				_tmp9_ = w;
#line 38 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
				_tmp10_ = gtk_widget_get_visible (_tmp9_);
#line 38 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
				if (!_tmp10_) {
#line 39 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
					continue;
#line 750 "wizard-source.c"
				}
#line 41 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
				_tmp11_ = w;
#line 41 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
				gtk_widget_get_preferred_height (_tmp11_, NULL, &_tmp12_);
#line 41 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
				child_height = _tmp12_;
#line 42 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
				_tmp13_ = height;
#line 42 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
				_tmp14_ = child_height;
#line 42 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
				height = _tmp13_ + _tmp14_;
#line 43 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
				_tmp15_ = i;
#line 43 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
				i = _tmp15_ + 1;
#line 44 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
				_tmp16_ = i;
#line 44 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
				_tmp17_ = self->priv->num_visible;
#line 44 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
				if (_tmp16_ == _tmp17_) {
#line 45 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
					break;
#line 776 "wizard-source.c"
				}
			}
		}
#line 37 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_g_list_free0 (w_collection);
#line 782 "wizard-source.c"
	}
#line 47 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp18_ = _vala_minimum_height;
#line 47 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp19_ = height;
#line 47 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp20_ = MAX (_tmp18_, _tmp19_);
#line 47 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_vala_minimum_height = _tmp20_;
#line 48 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp21_ = _vala_natural_height;
#line 48 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp22_ = height;
#line 48 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp23_ = MAX (_tmp21_, _tmp22_);
#line 48 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_vala_natural_height = _tmp23_;
#line 30 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (box);
#line 30 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (viewport);
#line 30 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	if (minimum_height) {
#line 30 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		*minimum_height = _vala_minimum_height;
#line 808 "wizard-source.c"
	}
#line 30 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	if (natural_height) {
#line 30 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		*natural_height = _vala_natural_height;
#line 814 "wizard-source.c"
	}
}


static void boxes_wizard_scrolled_class_init (BoxesWizardScrolledClass * klass) {
#line 14 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	boxes_wizard_scrolled_parent_class = g_type_class_peek_parent (klass);
#line 14 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	g_type_class_add_private (klass, sizeof (BoxesWizardScrolledPrivate));
#line 14 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	GTK_WIDGET_CLASS (klass)->get_preferred_height = boxes_wizard_scrolled_real_get_preferred_height;
#line 14 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_wizard_scrolled_finalize;
#line 828 "wizard-source.c"
}


static void boxes_wizard_scrolled_instance_init (BoxesWizardScrolled * self) {
#line 14 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	self->priv = BOXES_WIZARD_SCROLLED_GET_PRIVATE (self);
#line 835 "wizard-source.c"
}


static void boxes_wizard_scrolled_finalize (GObject* obj) {
	BoxesWizardScrolled * self;
#line 14 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_WIZARD_SCROLLED, BoxesWizardScrolled);
#line 14 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	G_OBJECT_CLASS (boxes_wizard_scrolled_parent_class)->finalize (obj);
#line 845 "wizard-source.c"
}


GType boxes_wizard_scrolled_get_type (void) {
	static volatile gsize boxes_wizard_scrolled_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_wizard_scrolled_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesWizardScrolledClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_wizard_scrolled_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesWizardScrolled), 0, (GInstanceInitFunc) boxes_wizard_scrolled_instance_init, NULL };
		GType boxes_wizard_scrolled_type_id;
		boxes_wizard_scrolled_type_id = g_type_register_static (GTK_TYPE_SCROLLED_WINDOW, "BoxesWizardScrolled", &g_define_type_info, 0);
		g_once_init_leave (&boxes_wizard_scrolled_type_id__volatile, boxes_wizard_scrolled_type_id);
	}
	return boxes_wizard_scrolled_type_id__volatile;
}


static gboolean __lambda185_ (BoxesWizardSource* self) {
	gboolean result = FALSE;
#line 115 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	boxes_wizard_source_set_page (self, BOXES_SOURCE_PAGE_URL);
#line 117 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	result = FALSE;
#line 117 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	return result;
#line 869 "wizard-source.c"
}


static gboolean ___lambda185__clicked_func (gpointer self) {
	gboolean result;
	result = __lambda185_ (self);
#line 114 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	return result;
#line 878 "wizard-source.c"
}


static gboolean _boxes_wizard_source_launch_file_selection_dialog_clicked_func (gpointer self) {
	gboolean result;
	result = boxes_wizard_source_launch_file_selection_dialog (self);
#line 125 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	return result;
#line 887 "wizard-source.c"
}


static gboolean __lambda187_ (BoxesWizardSource* self) {
	gboolean result = FALSE;
#line 139 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	boxes_wizard_source_set_selected (self, NULL);
#line 140 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	boxes_wizard_source_set_page (self, BOXES_SOURCE_PAGE_MAIN);
#line 142 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	result = FALSE;
#line 142 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	return result;
#line 901 "wizard-source.c"
}


static gboolean ___lambda187__clicked_func (gpointer self) {
	gboolean result;
	result = __lambda187_ (self);
#line 138 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	return result;
#line 910 "wizard-source.c"
}


BoxesWizardSource* boxes_wizard_source_construct (GType object_type, BoxesMediaManager* media_manager) {
	BoxesWizardSource * self = NULL;
	BoxesMediaManager* _tmp0_ = NULL;
	BoxesMediaManager* _tmp1_ = NULL;
	GtkNotebook* _tmp2_ = NULL;
	GtkNotebook* _tmp3_ = NULL;
	GtkNotebook* _tmp4_ = NULL;
	GtkStyleContext* _tmp5_ = NULL;
	GtkNotebook* _tmp6_ = NULL;
	GtkBox* _tmp7_ = NULL;
	GtkBox* _tmp8_ = NULL;
	GtkStyleContext* _tmp9_ = NULL;
	GtkBox* _tmp10_ = NULL;
	GtkBox* _tmp11_ = NULL;
	GtkBox* _tmp12_ = NULL;
	GtkNotebook* _tmp13_ = NULL;
	GtkBox* _tmp14_ = NULL;
	BoxesWizardScrolled* _tmp15_ = NULL;
	GtkBox* _tmp16_ = NULL;
	GtkScrolledWindow* _tmp17_ = NULL;
	GtkScrolledWindow* _tmp18_ = NULL;
	GtkBox* _tmp19_ = NULL;
	GtkBox* _tmp20_ = NULL;
	GtkScrolledWindow* _tmp21_ = NULL;
	GtkBox* hbox = NULL;
	GtkBox* _tmp22_ = NULL;
	GtkBox* _tmp23_ = NULL;
	GtkLabel* label = NULL;
	const gchar* _tmp24_ = NULL;
	GtkLabel* _tmp25_ = NULL;
	GtkLabel* _tmp26_ = NULL;
	GtkBox* _tmp27_ = NULL;
	GtkLabel* _tmp28_ = NULL;
	GtkLabel* next = NULL;
	GtkLabel* _tmp29_ = NULL;
	GtkBox* _tmp30_ = NULL;
	GtkLabel* _tmp31_ = NULL;
	GtkBox* _tmp32_ = NULL;
	GtkBox* _tmp33_ = NULL;
	const gchar* _tmp34_ = NULL;
	GtkLabel* _tmp35_ = NULL;
	GtkLabel* _tmp36_ = NULL;
	GtkBox* _tmp37_ = NULL;
	GtkLabel* _tmp38_ = NULL;
	GtkLabel* _tmp39_ = NULL;
	GtkBox* _tmp40_ = NULL;
	GtkLabel* _tmp41_ = NULL;
	GtkBox* url_menubox = NULL;
	GtkBox* _tmp42_ = NULL;
	GtkStyleContext* _tmp43_ = NULL;
	GtkNotebook* _tmp44_ = NULL;
	GtkBox* _tmp45_ = NULL;
	GtkLabel* prev = NULL;
	GtkLabel* _tmp46_ = NULL;
	GtkBox* _tmp47_ = NULL;
	const gchar* _tmp48_ = NULL;
	GtkLabel* _tmp49_ = NULL;
	GtkLabel* _tmp50_ = NULL;
	GtkStyleContext* _tmp51_ = NULL;
	GtkBox* _tmp52_ = NULL;
	GtkLabel* _tmp53_ = NULL;
	GtkBox* vbox = NULL;
	GtkBox* _tmp54_ = NULL;
	GtkEntry* _tmp55_ = NULL;
	GtkEntry* _tmp56_ = NULL;
	GtkBox* _tmp57_ = NULL;
	GtkImage* _tmp58_ = NULL;
	GtkImage* _tmp59_ = NULL;
	GtkBox* _tmp60_ = NULL;
	GtkImage* _tmp61_ = NULL;
	GtkLabel* _tmp62_ = NULL;
	GtkLabel* _tmp63_ = NULL;
	GtkLabel* _tmp64_ = NULL;
	const gchar* _tmp65_ = NULL;
	GtkLabel* _tmp66_ = NULL;
	GtkLabel* _tmp67_ = NULL;
	GtkLabel* _tmp68_ = NULL;
	GtkBox* _tmp69_ = NULL;
	GtkLabel* _tmp70_ = NULL;
	GtkBox* _tmp71_ = NULL;
	GtkNotebook* _tmp72_ = NULL;
#line 92 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	g_return_val_if_fail (media_manager != NULL, NULL);
#line 92 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	self = (BoxesWizardSource*) g_object_new (object_type, NULL);
#line 93 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp0_ = media_manager;
#line 93 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 93 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (self->priv->media_manager);
#line 93 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	self->priv->media_manager = _tmp1_;
#line 95 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp2_ = (GtkNotebook*) gtk_notebook_new ();
#line 95 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	g_object_ref_sink (_tmp2_);
#line 95 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (self->priv->notebook);
#line 95 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	self->priv->notebook = _tmp2_;
#line 96 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp3_ = self->priv->notebook;
#line 96 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	g_object_set ((GtkWidget*) _tmp3_, "width-request", 500, NULL);
#line 97 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp4_ = self->priv->notebook;
#line 97 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp5_ = gtk_widget_get_style_context ((GtkWidget*) _tmp4_);
#line 97 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	gtk_style_context_add_class (_tmp5_, "boxes-source-nb");
#line 98 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp6_ = self->priv->notebook;
#line 98 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	gtk_notebook_set_show_tabs (_tmp6_, FALSE);
#line 101 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp7_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
#line 101 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	g_object_ref_sink (_tmp7_);
#line 101 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (self->priv->main_vbox);
#line 101 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	self->priv->main_vbox = _tmp7_;
#line 102 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp8_ = self->priv->main_vbox;
#line 102 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp9_ = gtk_widget_get_style_context ((GtkWidget*) _tmp8_);
#line 102 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	gtk_style_context_add_class (_tmp9_, "boxes-menu");
#line 103 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp10_ = self->priv->main_vbox;
#line 103 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp11_ = self->priv->main_vbox;
#line 103 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	gtk_widget_set_margin_bottom ((GtkWidget*) _tmp11_, 15);
#line 103 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	gtk_widget_set_margin_top ((GtkWidget*) _tmp10_, 15);
#line 104 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp12_ = self->priv->main_vbox;
#line 104 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	gtk_widget_grab_focus ((GtkWidget*) _tmp12_);
#line 105 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp13_ = self->priv->notebook;
#line 105 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp14_ = self->priv->main_vbox;
#line 105 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	gtk_notebook_append_page (_tmp13_, (GtkWidget*) _tmp14_, NULL);
#line 107 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp15_ = boxes_wizard_scrolled_new (6);
#line 107 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	g_object_ref_sink (_tmp15_);
#line 107 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (self->priv->media_scrolled);
#line 107 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	self->priv->media_scrolled = (GtkScrolledWindow*) _tmp15_;
#line 109 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp16_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
#line 109 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	g_object_ref_sink (_tmp16_);
#line 109 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (self->priv->media_vbox);
#line 109 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	self->priv->media_vbox = _tmp16_;
#line 110 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp17_ = self->priv->media_scrolled;
#line 110 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	gtk_widget_set_no_show_all ((GtkWidget*) _tmp17_, TRUE);
#line 111 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp18_ = self->priv->media_scrolled;
#line 111 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp19_ = self->priv->media_vbox;
#line 111 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	gtk_scrolled_window_add_with_viewport (_tmp18_, (GtkWidget*) _tmp19_);
#line 112 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp20_ = self->priv->main_vbox;
#line 112 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp21_ = self->priv->media_scrolled;
#line 112 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	gtk_container_add ((GtkContainer*) _tmp20_, (GtkWidget*) _tmp21_);
#line 114 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp22_ = self->priv->main_vbox;
#line 114 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp23_ = boxes_wizard_source_add_entry (self, _tmp22_, ___lambda185__clicked_func, g_object_ref (self), g_object_unref, 20, 10, NULL);
#line 114 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	hbox = _tmp23_;
#line 119 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp24_ = _ ("Enter URL");
#line 119 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp25_ = (GtkLabel*) gtk_label_new (_tmp24_);
#line 119 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	g_object_ref_sink (_tmp25_);
#line 119 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	label = _tmp25_;
#line 120 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp26_ = label;
#line 120 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	g_object_set ((GtkMisc*) _tmp26_, "xalign", 0.0f, NULL);
#line 121 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp27_ = hbox;
#line 121 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp28_ = label;
#line 121 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	gtk_box_pack_start (_tmp27_, (GtkWidget*) _tmp28_, TRUE, TRUE, (guint) 0);
#line 122 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp29_ = (GtkLabel*) gtk_label_new ("▶");
#line 122 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	g_object_ref_sink (_tmp29_);
#line 122 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	next = _tmp29_;
#line 123 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp30_ = hbox;
#line 123 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp31_ = next;
#line 123 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	gtk_box_pack_start (_tmp30_, (GtkWidget*) _tmp31_, FALSE, FALSE, (guint) 0);
#line 125 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp32_ = self->priv->main_vbox;
#line 125 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp33_ = boxes_wizard_source_add_entry (self, _tmp32_, _boxes_wizard_source_launch_file_selection_dialog_clicked_func, g_object_ref (self), g_object_unref, 20, 10, NULL);
#line 125 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (hbox);
#line 125 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	hbox = _tmp33_;
#line 126 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp34_ = _ ("Select a file");
#line 126 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp35_ = (GtkLabel*) gtk_label_new (_tmp34_);
#line 126 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	g_object_ref_sink (_tmp35_);
#line 126 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (label);
#line 126 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	label = _tmp35_;
#line 127 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp36_ = label;
#line 127 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	g_object_set ((GtkMisc*) _tmp36_, "xalign", 0.0f, NULL);
#line 128 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp37_ = hbox;
#line 128 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp38_ = label;
#line 128 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	gtk_box_pack_start (_tmp37_, (GtkWidget*) _tmp38_, TRUE, TRUE, (guint) 0);
#line 129 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp39_ = (GtkLabel*) gtk_label_new ("▶");
#line 129 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	g_object_ref_sink (_tmp39_);
#line 129 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (next);
#line 129 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	next = _tmp39_;
#line 130 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp40_ = hbox;
#line 130 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp41_ = next;
#line 130 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	gtk_box_pack_start (_tmp40_, (GtkWidget*) _tmp41_, FALSE, FALSE, (guint) 0);
#line 133 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp42_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
#line 133 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	g_object_ref_sink (_tmp42_);
#line 133 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	url_menubox = _tmp42_;
#line 134 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp43_ = gtk_widget_get_style_context ((GtkWidget*) url_menubox);
#line 134 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	gtk_style_context_add_class (_tmp43_, "boxes-menu");
#line 135 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	gtk_widget_set_margin_bottom ((GtkWidget*) url_menubox, 15);
#line 135 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	gtk_widget_set_margin_top ((GtkWidget*) url_menubox, 15);
#line 136 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp44_ = self->priv->notebook;
#line 136 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	gtk_notebook_append_page (_tmp44_, (GtkWidget*) url_menubox, NULL);
#line 138 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp45_ = boxes_wizard_source_add_entry (self, url_menubox, ___lambda187__clicked_func, g_object_ref (self), g_object_unref, 20, 10, NULL);
#line 138 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (hbox);
#line 138 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	hbox = _tmp45_;
#line 144 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp46_ = (GtkLabel*) gtk_label_new ("◀");
#line 144 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	g_object_ref_sink (_tmp46_);
#line 144 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	prev = _tmp46_;
#line 145 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp47_ = hbox;
#line 145 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	gtk_box_pack_start (_tmp47_, (GtkWidget*) prev, FALSE, FALSE, (guint) 0);
#line 146 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp48_ = _ ("Enter URL");
#line 146 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp49_ = (GtkLabel*) gtk_label_new (_tmp48_);
#line 146 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	g_object_ref_sink (_tmp49_);
#line 146 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (label);
#line 146 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	label = _tmp49_;
#line 147 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp50_ = label;
#line 147 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp51_ = gtk_widget_get_style_context ((GtkWidget*) _tmp50_);
#line 147 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	gtk_style_context_add_class (_tmp51_, "boxes-source-label");
#line 148 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp52_ = hbox;
#line 148 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp53_ = label;
#line 148 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	gtk_box_pack_start (_tmp52_, (GtkWidget*) _tmp53_, TRUE, TRUE, (guint) 0);
#line 150 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp54_ = boxes_wizard_source_add_entry (self, url_menubox, NULL, NULL, NULL, 20, 10, NULL);
#line 150 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	vbox = _tmp54_;
#line 151 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	gtk_orientable_set_orientation ((GtkOrientable*) vbox, GTK_ORIENTATION_VERTICAL);
#line 152 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp55_ = (GtkEntry*) gtk_entry_new ();
#line 152 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	g_object_ref_sink (_tmp55_);
#line 152 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (self->url_entry);
#line 152 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	self->url_entry = _tmp55_;
#line 153 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp56_ = self->url_entry;
#line 153 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	gtk_container_add ((GtkContainer*) vbox, (GtkWidget*) _tmp56_);
#line 155 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp57_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
#line 155 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	g_object_ref_sink (_tmp57_);
#line 155 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (hbox);
#line 155 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	hbox = _tmp57_;
#line 156 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp58_ = (GtkImage*) gtk_image_new_from_icon_name ("network-workgroup", 0);
#line 156 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	g_object_ref_sink (_tmp58_);
#line 156 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (self->priv->url_image);
#line 156 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	self->priv->url_image = _tmp58_;
#line 158 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp59_ = self->priv->url_image;
#line 158 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	gtk_image_set_pixel_size (_tmp59_, 96);
#line 159 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp60_ = hbox;
#line 159 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp61_ = self->priv->url_image;
#line 159 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	gtk_box_pack_start (_tmp60_, (GtkWidget*) _tmp61_, FALSE, FALSE, (guint) 0);
#line 161 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp62_ = (GtkLabel*) gtk_label_new (NULL);
#line 161 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	g_object_ref_sink (_tmp62_);
#line 161 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (self->priv->url_label);
#line 161 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	self->priv->url_label = _tmp62_;
#line 162 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp63_ = self->priv->url_label;
#line 162 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	g_object_set ((GtkMisc*) _tmp63_, "xalign", 0.0f, NULL);
#line 163 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp64_ = self->priv->url_label;
#line 163 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp65_ = _ ("<b>Desktop Access</b>\n" \
"\n" \
"Will add boxes for all systems available from this account.");
#line 163 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	gtk_label_set_markup (_tmp64_, _tmp65_);
#line 164 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp66_ = self->priv->url_label;
#line 164 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	gtk_label_set_use_markup (_tmp66_, TRUE);
#line 165 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp67_ = self->priv->url_label;
#line 165 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	g_object_set (_tmp67_, "wrap", TRUE, NULL);
#line 167 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp68_ = self->priv->url_label;
#line 167 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	gtk_label_set_width_chars (_tmp68_, 30);
#line 169 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp69_ = hbox;
#line 169 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp70_ = self->priv->url_label;
#line 169 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	gtk_box_pack_start (_tmp69_, (GtkWidget*) _tmp70_, TRUE, TRUE, (guint) 0);
#line 170 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp71_ = hbox;
#line 170 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	gtk_container_add ((GtkContainer*) vbox, (GtkWidget*) _tmp71_);
#line 172 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp72_ = self->priv->notebook;
#line 172 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	gtk_widget_show_all ((GtkWidget*) _tmp72_);
#line 174 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	boxes_wizard_source_add_media_entries (self, NULL, NULL);
#line 92 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (vbox);
#line 92 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (prev);
#line 92 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (url_menubox);
#line 92 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (next);
#line 92 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (label);
#line 92 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (hbox);
#line 92 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	return self;
#line 1331 "wizard-source.c"
}


BoxesWizardSource* boxes_wizard_source_new (BoxesMediaManager* media_manager) {
#line 92 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	return boxes_wizard_source_construct (BOXES_TYPE_WIZARD_SOURCE, media_manager);
#line 1338 "wizard-source.c"
}


void boxes_wizard_source_update_url_page (BoxesWizardSource* self, const gchar* title, const gchar* text, const gchar* icon_name) {
	GtkLabel* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	gchar* _tmp4_ = NULL;
	gchar* _tmp5_ = NULL;
	const gchar* _tmp6_ = NULL;
	gchar* _tmp7_ = NULL;
	gchar* _tmp8_ = NULL;
	GtkImage* _tmp9_ = NULL;
	const gchar* _tmp10_ = NULL;
#line 177 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	g_return_if_fail (self != NULL);
#line 177 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	g_return_if_fail (title != NULL);
#line 177 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	g_return_if_fail (text != NULL);
#line 177 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	g_return_if_fail (icon_name != NULL);
#line 178 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp0_ = self->priv->url_label;
#line 178 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp1_ = title;
#line 178 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp2_ = g_strconcat ("<b>", _tmp1_, NULL);
#line 178 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp3_ = _tmp2_;
#line 178 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp4_ = g_strconcat (_tmp3_, "</b>\n\n", NULL);
#line 178 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp5_ = _tmp4_;
#line 178 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp6_ = text;
#line 178 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp7_ = g_strconcat (_tmp5_, _tmp6_, NULL);
#line 178 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp8_ = _tmp7_;
#line 178 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	gtk_label_set_markup (_tmp0_, _tmp8_);
#line 178 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_g_free0 (_tmp8_);
#line 178 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_g_free0 (_tmp5_);
#line 178 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_g_free0 (_tmp3_);
#line 179 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp9_ = self->priv->url_image;
#line 179 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp10_ = icon_name;
#line 179 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	g_object_set (_tmp9_, "icon-name", _tmp10_, NULL);
#line 1394 "wizard-source.c"
}


static void boxes_wizard_source_add_media_entries_data_free (gpointer _data) {
	BoxesWizardSourceAddMediaEntriesData* _data_;
	_data_ = _data;
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (_data_->self);
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	g_slice_free (BoxesWizardSourceAddMediaEntriesData, _data_);
#line 1405 "wizard-source.c"
}


static void boxes_wizard_source_add_media_entries (BoxesWizardSource* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesWizardSourceAddMediaEntriesData* _data_;
	BoxesWizardSource* _tmp0_ = NULL;
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_data_ = g_slice_new0 (BoxesWizardSourceAddMediaEntriesData);
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, boxes_wizard_source_add_media_entries);
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_wizard_source_add_media_entries_data_free);
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_data_->self = _tmp0_;
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	boxes_wizard_source_add_media_entries_co (_data_);
#line 1424 "wizard-source.c"
}


static void boxes_wizard_source_add_media_entries_finish (BoxesWizardSource* self, GAsyncResult* _res_) {
	BoxesWizardSourceAddMediaEntriesData* _data_;
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 1432 "wizard-source.c"
}


static void boxes_wizard_source_add_media_entries_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesWizardSourceAddMediaEntriesData* _data_;
#line 183 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_data_ = _user_data_;
#line 183 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_data_->_source_object_ = source_object;
#line 183 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_data_->_res_ = _res_;
#line 183 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	boxes_wizard_source_add_media_entries_co (_data_);
#line 1446 "wizard-source.c"
}


static void _g_object_unref0_ (gpointer var) {
#line 182 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	(var == NULL) ? NULL : (var = (g_object_unref (var), NULL));
#line 1453 "wizard-source.c"
}


static void _g_list_free__g_object_unref0_ (GList* self) {
#line 182 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	g_list_foreach (self, (GFunc) _g_object_unref0_, NULL);
#line 182 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	g_list_free (self);
#line 1462 "wizard-source.c"
}


static gboolean boxes_wizard_source_add_media_entries_co (BoxesWizardSourceAddMediaEntriesData* _data_) {
#line 182 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	switch (_data_->_state_) {
#line 182 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		case 0:
#line 1471 "wizard-source.c"
		goto _state_0;
#line 182 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		case 1:
#line 1475 "wizard-source.c"
		goto _state_1;
		default:
#line 182 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		g_assert_not_reached ();
#line 1480 "wizard-source.c"
	}
	_state_0:
#line 183 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_data_->_tmp0_ = NULL;
#line 183 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_data_->_tmp0_ = _data_->self->priv->media_manager;
#line 183 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_data_->_state_ = 1;
#line 183 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	boxes_media_manager_list_installer_medias (_data_->_tmp0_, boxes_wizard_source_add_media_entries_ready, _data_);
#line 183 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	return FALSE;
#line 1493 "wizard-source.c"
	_state_1:
#line 183 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_data_->_tmp1_ = NULL;
#line 183 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_data_->_tmp1_ = boxes_media_manager_list_installer_medias_finish (_data_->_tmp0_, _data_->_res_);
#line 183 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_data_->medias = _data_->_tmp1_;
#line 185 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_data_->_tmp2_ = NULL;
#line 185 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_data_->_tmp2_ = _data_->self->priv->media_vbox;
#line 185 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_data_->_tmp3_ = NULL;
#line 185 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_data_->_tmp3_ = gtk_container_get_children ((GtkContainer*) _data_->_tmp2_);
#line 1509 "wizard-source.c"
	{
#line 185 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_data_->child_collection = _data_->_tmp3_;
#line 185 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		for (_data_->child_it = _data_->child_collection; _data_->child_it != NULL; _data_->child_it = _data_->child_it->next) {
#line 185 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
			_data_->child = (GtkWidget*) _data_->child_it->data;
#line 1517 "wizard-source.c"
			{
#line 186 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
				_data_->_tmp4_ = NULL;
#line 186 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
				_data_->_tmp4_ = _data_->child;
#line 186 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
				_data_->_tmp5_ = NULL;
#line 186 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
				_data_->_tmp5_ = g_object_get_data ((GObject*) _data_->_tmp4_, "boxes-media");
#line 186 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
				_data_->_tmp6_ = NULL;
#line 186 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
				_data_->_tmp6_ = g_strdup ((const gchar*) _data_->_tmp5_);
#line 186 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
				_data_->child_media = _data_->_tmp6_;
#line 187 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
				_data_->_tmp7_ = NULL;
#line 187 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
				_data_->_tmp7_ = _data_->child_media;
#line 187 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
				if (_data_->_tmp7_ == NULL) {
#line 188 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
					_g_free0 (_data_->child_media);
#line 188 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
					continue;
#line 1543 "wizard-source.c"
				}
#line 190 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
				_data_->obsolete = TRUE;
#line 191 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
				_data_->_tmp8_ = NULL;
#line 191 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
				_data_->_tmp8_ = _data_->medias;
#line 1551 "wizard-source.c"
				{
#line 191 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
					_data_->media_collection = _data_->_tmp8_;
#line 191 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
					for (_data_->media_it = _data_->media_collection; _data_->media_it != NULL; _data_->media_it = _data_->media_it->next) {
#line 191 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
						_data_->_tmp9_ = NULL;
#line 191 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
						_data_->_tmp9_ = _g_object_ref0 ((BoxesInstallerMedia*) _data_->media_it->data);
#line 191 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
						_data_->media = _data_->_tmp9_;
#line 1563 "wizard-source.c"
						{
#line 192 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
							_data_->_tmp10_ = NULL;
#line 192 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
							_data_->_tmp10_ = _data_->child_media;
#line 192 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
							_data_->_tmp11_ = NULL;
#line 192 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
							_data_->_tmp11_ = _data_->media;
#line 192 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
							_data_->_tmp12_ = NULL;
#line 192 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
							_data_->_tmp12_ = _data_->_tmp11_->device_file;
#line 192 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
							if (g_strcmp0 (_data_->_tmp10_, _data_->_tmp12_) == 0) {
#line 193 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
								_data_->obsolete = FALSE;
#line 195 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
								_g_object_unref0 (_data_->media);
#line 195 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
								break;
#line 1585 "wizard-source.c"
							}
#line 191 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
							_g_object_unref0 (_data_->media);
#line 1589 "wizard-source.c"
						}
					}
				}
#line 198 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
				_data_->_tmp13_ = FALSE;
#line 198 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
				_data_->_tmp13_ = _data_->obsolete;
#line 198 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
				if (_data_->_tmp13_) {
#line 199 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
					_data_->_tmp14_ = NULL;
#line 199 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
					_data_->_tmp14_ = _data_->self->priv->main_vbox;
#line 199 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
					_data_->_tmp15_ = NULL;
#line 199 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
					_data_->_tmp15_ = _data_->child;
#line 199 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
					gtk_container_remove ((GtkContainer*) _data_->_tmp14_, _data_->_tmp15_);
#line 1609 "wizard-source.c"
				}
#line 185 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
				_g_free0 (_data_->child_media);
#line 1613 "wizard-source.c"
			}
		}
#line 185 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_g_list_free0 (_data_->child_collection);
#line 1618 "wizard-source.c"
	}
#line 202 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_data_->_tmp16_ = NULL;
#line 202 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_data_->_tmp16_ = _data_->medias;
#line 1624 "wizard-source.c"
	{
#line 202 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_data_->_vala1_media_collection = _data_->_tmp16_;
#line 202 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		for (_data_->_vala1_media_it = _data_->_vala1_media_collection; _data_->_vala1_media_it != NULL; _data_->_vala1_media_it = _data_->_vala1_media_it->next) {
#line 202 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
			_data_->_tmp17_ = NULL;
#line 202 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
			_data_->_tmp17_ = _g_object_ref0 ((BoxesInstallerMedia*) _data_->_vala1_media_it->data);
#line 202 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
			_data_->_vala1_media = _data_->_tmp17_;
#line 1636 "wizard-source.c"
			{
#line 203 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
				_data_->nouveau = TRUE;
#line 204 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
				_data_->_tmp18_ = NULL;
#line 204 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
				_data_->_tmp18_ = _data_->self->priv->media_vbox;
#line 204 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
				_data_->_tmp19_ = NULL;
#line 204 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
				_data_->_tmp19_ = gtk_container_get_children ((GtkContainer*) _data_->_tmp18_);
#line 1648 "wizard-source.c"
				{
#line 204 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
					_data_->_vala1_child_collection = _data_->_tmp19_;
#line 204 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
					for (_data_->_vala1_child_it = _data_->_vala1_child_collection; _data_->_vala1_child_it != NULL; _data_->_vala1_child_it = _data_->_vala1_child_it->next) {
#line 204 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
						_data_->_vala1_child = (GtkWidget*) _data_->_vala1_child_it->data;
#line 1656 "wizard-source.c"
						{
#line 205 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
							_data_->_tmp20_ = NULL;
#line 205 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
							_data_->_tmp20_ = _data_->_vala1_child;
#line 205 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
							_data_->_tmp21_ = NULL;
#line 205 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
							_data_->_tmp21_ = g_object_get_data ((GObject*) _data_->_tmp20_, "boxes-media");
#line 205 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
							_data_->_tmp22_ = NULL;
#line 205 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
							_data_->_tmp22_ = g_strdup ((const gchar*) _data_->_tmp21_);
#line 205 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
							_data_->_vala1_child_media = _data_->_tmp22_;
#line 206 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
							_data_->_tmp24_ = NULL;
#line 206 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
							_data_->_tmp24_ = _data_->_vala1_child_media;
#line 206 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
							if (_data_->_tmp24_ != NULL) {
#line 206 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
								_data_->_tmp25_ = NULL;
#line 206 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
								_data_->_tmp25_ = _data_->_vala1_child_media;
#line 206 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
								_data_->_tmp26_ = NULL;
#line 206 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
								_data_->_tmp26_ = _data_->_vala1_media;
#line 206 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
								_data_->_tmp27_ = NULL;
#line 206 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
								_data_->_tmp27_ = _data_->_tmp26_->device_file;
#line 206 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
								_data_->_tmp23_ = g_strcmp0 (_data_->_tmp25_, _data_->_tmp27_) == 0;
#line 1692 "wizard-source.c"
							} else {
#line 206 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
								_data_->_tmp23_ = FALSE;
#line 1696 "wizard-source.c"
							}
#line 206 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
							_data_->_tmp28_ = FALSE;
#line 206 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
							_data_->_tmp28_ = _data_->_tmp23_;
#line 206 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
							if (_data_->_tmp28_) {
#line 207 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
								_data_->nouveau = FALSE;
#line 209 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
								_g_free0 (_data_->_vala1_child_media);
#line 209 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
								break;
#line 1710 "wizard-source.c"
							}
#line 204 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
							_g_free0 (_data_->_vala1_child_media);
#line 1714 "wizard-source.c"
						}
					}
#line 204 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
					_g_list_free0 (_data_->_vala1_child_collection);
#line 1719 "wizard-source.c"
				}
#line 213 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
				_data_->_tmp29_ = FALSE;
#line 213 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
				_data_->_tmp29_ = _data_->nouveau;
#line 213 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
				if (_data_->_tmp29_) {
#line 214 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
					_data_->_tmp30_ = NULL;
#line 214 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
					_data_->_tmp30_ = _data_->_vala1_media;
#line 214 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
					boxes_wizard_source_add_media_entry (_data_->self, _data_->_tmp30_);
#line 1733 "wizard-source.c"
				}
#line 202 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
				_g_object_unref0 (_data_->_vala1_media);
#line 1737 "wizard-source.c"
			}
		}
	}
#line 218 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_data_->_tmp31_ = NULL;
#line 218 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_data_->_tmp31_ = _data_->self->priv->media_vbox;
#line 218 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_data_->_tmp32_ = NULL;
#line 218 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_data_->_tmp32_ = gtk_container_get_children ((GtkContainer*) _data_->_tmp31_);
#line 218 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_data_->_tmp33_ = NULL;
#line 218 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_data_->_tmp33_ = _data_->_tmp32_;
#line 218 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_data_->_tmp34_ = 0U;
#line 218 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_data_->_tmp34_ = g_list_length (_data_->_tmp33_);
#line 218 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_data_->_tmp35_ = FALSE;
#line 218 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_data_->_tmp35_ = _data_->_tmp34_ == ((guint) 0);
#line 218 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_g_list_free0 (_data_->_tmp33_);
#line 218 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	if (_data_->_tmp35_) {
#line 219 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_data_->_tmp36_ = NULL;
#line 219 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_data_->_tmp36_ = _data_->self->priv->media_scrolled;
#line 219 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		gtk_widget_hide ((GtkWidget*) _data_->_tmp36_);
#line 1771 "wizard-source.c"
	}
#line 182 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	__g_list_free__g_object_unref0_0 (_data_->medias);
#line 182 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	if (_data_->_state_ == 0) {
#line 182 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1779 "wizard-source.c"
	} else {
#line 182 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 1783 "wizard-source.c"
	}
#line 182 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	g_object_unref (_data_->_async_result);
#line 182 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	return FALSE;
#line 1789 "wizard-source.c"
}


static Block72Data* block72_data_ref (Block72Data* _data72_) {
#line 222 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	g_atomic_int_inc (&_data72_->_ref_count_);
#line 222 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	return _data72_;
#line 1798 "wizard-source.c"
}


static void block72_data_unref (void * _userdata_) {
	Block72Data* _data72_;
	_data72_ = (Block72Data*) _userdata_;
#line 222 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	if (g_atomic_int_dec_and_test (&_data72_->_ref_count_)) {
#line 1807 "wizard-source.c"
		BoxesWizardSource * self;
#line 222 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		self = _data72_->self;
#line 222 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_g_object_unref0 (_data72_->media);
#line 222 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_g_object_unref0 (self);
#line 222 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		g_slice_free (Block72Data, _data72_);
#line 1817 "wizard-source.c"
	}
}


static gboolean __lambda186_ (Block72Data* _data72_) {
	BoxesWizardSource * self;
	gboolean result = FALSE;
	BoxesInstallerMedia* _tmp0_ = NULL;
#line 223 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	self = _data72_->self;
#line 224 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp0_ = _data72_->media;
#line 224 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	boxes_wizard_source_on_media_selected (self, _tmp0_);
#line 226 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	result = TRUE;
#line 226 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	return result;
#line 1836 "wizard-source.c"
}


static gboolean ___lambda186__clicked_func (gpointer self) {
	gboolean result;
	result = __lambda186_ (self);
#line 223 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	return result;
#line 1845 "wizard-source.c"
}


static void boxes_wizard_source_add_media_entry (BoxesWizardSource* self, BoxesInstallerMedia* media) {
	Block72Data* _data72_;
	BoxesInstallerMedia* _tmp0_ = NULL;
	BoxesInstallerMedia* _tmp1_ = NULL;
	GtkBox* hbox = NULL;
	GtkBox* _tmp2_ = NULL;
	BoxesInstallerMedia* _tmp3_ = NULL;
	const gchar* _tmp4_ = NULL;
	GtkBox* _tmp5_ = NULL;
	GtkImage* image = NULL;
	GtkImage* _tmp6_ = NULL;
	GtkImage* _tmp7_ = NULL;
	GtkBox* _tmp8_ = NULL;
	GtkImage* _tmp9_ = NULL;
	BoxesInstallerMedia* _tmp10_ = NULL;
	OsinfoOs* _tmp11_ = NULL;
	GtkBox* vbox = NULL;
	GtkBox* _tmp15_ = NULL;
	GtkBox* _tmp16_ = NULL;
	GtkBox* _tmp17_ = NULL;
	GtkBox* _tmp18_ = NULL;
	gchar* media_label = NULL;
	BoxesInstallerMedia* _tmp19_ = NULL;
	const gchar* _tmp20_ = NULL;
	gchar* _tmp21_ = NULL;
	gboolean _tmp22_ = FALSE;
	BoxesInstallerMedia* _tmp23_ = NULL;
	OsinfoMedia* _tmp24_ = NULL;
	gboolean _tmp29_ = FALSE;
	GtkLabel* label = NULL;
	const gchar* _tmp37_ = NULL;
	GtkLabel* _tmp38_ = NULL;
	GtkLabel* _tmp39_ = NULL;
	GtkLabel* _tmp40_ = NULL;
	GtkStyleContext* _tmp41_ = NULL;
	GtkLabel* _tmp42_ = NULL;
	GtkBox* _tmp43_ = NULL;
	GtkLabel* _tmp44_ = NULL;
	BoxesInstallerMedia* _tmp45_ = NULL;
	OsinfoMedia* _tmp46_ = NULL;
	GtkBox* _tmp90_ = NULL;
	GtkScrolledWindow* _tmp91_ = NULL;
#line 222 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	g_return_if_fail (self != NULL);
#line 222 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	g_return_if_fail (media != NULL);
#line 222 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_data72_ = g_slice_new0 (Block72Data);
#line 222 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_data72_->_ref_count_ = 1;
#line 222 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_data72_->self = g_object_ref (self);
#line 222 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp0_ = media;
#line 222 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 222 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (_data72_->media);
#line 222 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_data72_->media = _tmp1_;
#line 223 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp2_ = self->priv->media_vbox;
#line 223 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp3_ = _data72_->media;
#line 223 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp4_ = _tmp3_->device_file;
#line 223 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp5_ = boxes_wizard_source_add_entry (self, _tmp2_, ___lambda186__clicked_func, block72_data_ref (_data72_), block72_data_unref, 15, 5, _tmp4_);
#line 223 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	hbox = _tmp5_;
#line 229 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp6_ = (GtkImage*) gtk_image_new_from_icon_name ("media-optical", 0);
#line 229 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	g_object_ref_sink (_tmp6_);
#line 229 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	image = _tmp6_;
#line 230 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp7_ = image;
#line 230 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	gtk_image_set_pixel_size (_tmp7_, 64);
#line 231 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp8_ = hbox;
#line 231 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp9_ = image;
#line 231 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	gtk_box_pack_start (_tmp8_, (GtkWidget*) _tmp9_, FALSE, FALSE, (guint) 0);
#line 233 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp10_ = _data72_->media;
#line 233 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp11_ = _tmp10_->os;
#line 233 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	if (_tmp11_ != NULL) {
#line 1941 "wizard-source.c"
		GtkImage* _tmp12_ = NULL;
		BoxesInstallerMedia* _tmp13_ = NULL;
		OsinfoOs* _tmp14_ = NULL;
#line 234 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_tmp12_ = image;
#line 234 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_tmp13_ = _data72_->media;
#line 234 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_tmp14_ = _tmp13_->os;
#line 234 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		boxes_downloader_fetch_os_logo (_tmp12_, _tmp14_, 64, NULL, NULL);
#line 1953 "wizard-source.c"
	}
#line 236 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp15_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_VERTICAL, 5);
#line 236 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	g_object_ref_sink (_tmp15_);
#line 236 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	vbox = _tmp15_;
#line 237 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp16_ = vbox;
#line 237 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	gtk_box_set_homogeneous (_tmp16_, TRUE);
#line 238 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp17_ = hbox;
#line 238 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp18_ = vbox;
#line 238 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	gtk_box_pack_start (_tmp17_, (GtkWidget*) _tmp18_, TRUE, TRUE, (guint) 0);
#line 240 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp19_ = _data72_->media;
#line 240 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp20_ = _tmp19_->label;
#line 240 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp21_ = g_strdup (_tmp20_);
#line 240 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	media_label = _tmp21_;
#line 241 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp23_ = _data72_->media;
#line 241 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp24_ = _tmp23_->os_media;
#line 241 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	if (_tmp24_ != NULL) {
#line 1985 "wizard-source.c"
		BoxesInstallerMedia* _tmp25_ = NULL;
		OsinfoMedia* _tmp26_ = NULL;
		gboolean _tmp27_ = FALSE;
		gboolean _tmp28_ = FALSE;
#line 241 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_tmp25_ = _data72_->media;
#line 241 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_tmp26_ = _tmp25_->os_media;
#line 241 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		g_object_get (_tmp26_, "live", &_tmp27_, NULL);
#line 241 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_tmp28_ = _tmp27_;
#line 241 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_tmp22_ = _tmp28_;
#line 2000 "wizard-source.c"
	} else {
#line 241 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_tmp22_ = FALSE;
#line 2004 "wizard-source.c"
	}
#line 241 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp29_ = _tmp22_;
#line 241 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	if (_tmp29_) {
#line 2010 "wizard-source.c"
		const gchar* _tmp30_ = NULL;
		const gchar* _tmp31_ = NULL;
		gchar* _tmp32_ = NULL;
		gchar* _tmp33_ = NULL;
		gchar* _tmp34_ = NULL;
		gchar* _tmp35_ = NULL;
		gchar* _tmp36_ = NULL;
#line 244 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_tmp30_ = media_label;
#line 244 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_tmp31_ = _ ("Live");
#line 244 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_tmp32_ = g_strconcat (" (", _tmp31_, NULL);
#line 244 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_tmp33_ = _tmp32_;
#line 244 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_tmp34_ = g_strconcat (_tmp33_, ")", NULL);
#line 244 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_tmp35_ = _tmp34_;
#line 244 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_tmp36_ = g_strconcat (_tmp30_, _tmp35_, NULL);
#line 244 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_g_free0 (media_label);
#line 244 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		media_label = _tmp36_;
#line 244 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_g_free0 (_tmp35_);
#line 244 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_g_free0 (_tmp33_);
#line 2040 "wizard-source.c"
	}
#line 245 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp37_ = media_label;
#line 245 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp38_ = (GtkLabel*) gtk_label_new (_tmp37_);
#line 245 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	g_object_ref_sink (_tmp38_);
#line 245 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	label = _tmp38_;
#line 246 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp39_ = label;
#line 246 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	gtk_label_set_ellipsize (_tmp39_, PANGO_ELLIPSIZE_END);
#line 247 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp40_ = label;
#line 247 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp41_ = gtk_widget_get_style_context ((GtkWidget*) _tmp40_);
#line 247 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	gtk_style_context_add_class (_tmp41_, "boxes-source-label");
#line 248 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp42_ = label;
#line 248 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	g_object_set ((GtkMisc*) _tmp42_, "xalign", 0.0f, NULL);
#line 249 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp43_ = vbox;
#line 249 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp44_ = label;
#line 249 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	gtk_box_pack_start (_tmp43_, (GtkWidget*) _tmp44_, TRUE, TRUE, (guint) 0);
#line 251 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp45_ = _data72_->media;
#line 251 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp46_ = _tmp45_->os_media;
#line 251 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	if (_tmp46_ != NULL) {
#line 2076 "wizard-source.c"
		const gchar* _tmp47_ = NULL;
		gboolean _tmp48_ = FALSE;
		BoxesInstallerMedia* _tmp49_ = NULL;
		OsinfoMedia* _tmp50_ = NULL;
		gchar* _tmp51_ = NULL;
		gchar* _tmp52_ = NULL;
		gchar* _tmp53_ = NULL;
		gboolean _tmp54_ = FALSE;
		gboolean _tmp60_ = FALSE;
		gchar* architecture = NULL;
		const gchar* _tmp63_ = NULL;
		gchar* _tmp64_ = NULL;
		const gchar* _tmp65_ = NULL;
		GtkLabel* _tmp66_ = NULL;
		GtkLabel* _tmp67_ = NULL;
		GtkLabel* _tmp68_ = NULL;
		GtkStyleContext* _tmp69_ = NULL;
		GtkLabel* _tmp70_ = NULL;
		GtkBox* _tmp71_ = NULL;
		GtkLabel* _tmp72_ = NULL;
		BoxesInstallerMedia* _tmp73_ = NULL;
		OsinfoOs* _tmp74_ = NULL;
		const gchar* _tmp75_ = NULL;
		const gchar* _tmp76_ = NULL;
#line 252 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_tmp49_ = _data72_->media;
#line 252 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_tmp50_ = _tmp49_->os_media;
#line 252 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		g_object_get (_tmp50_, "architecture", &_tmp51_, NULL);
#line 252 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_tmp52_ = _tmp51_;
#line 252 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_tmp53_ = _tmp52_;
#line 252 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_tmp54_ = g_strcmp0 (_tmp53_, "i386") == 0;
#line 252 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_g_free0 (_tmp53_);
#line 252 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		if (_tmp54_) {
#line 252 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
			_tmp48_ = TRUE;
#line 2119 "wizard-source.c"
		} else {
			BoxesInstallerMedia* _tmp55_ = NULL;
			OsinfoMedia* _tmp56_ = NULL;
			gchar* _tmp57_ = NULL;
			gchar* _tmp58_ = NULL;
			gchar* _tmp59_ = NULL;
#line 252 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
			_tmp55_ = _data72_->media;
#line 252 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
			_tmp56_ = _tmp55_->os_media;
#line 252 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
			g_object_get (_tmp56_, "architecture", &_tmp57_, NULL);
#line 252 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
			_tmp58_ = _tmp57_;
#line 252 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
			_tmp59_ = _tmp58_;
#line 252 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
			_tmp48_ = g_strcmp0 (_tmp59_, "i686") == 0;
#line 252 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
			_g_free0 (_tmp59_);
#line 2140 "wizard-source.c"
		}
#line 252 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_tmp60_ = _tmp48_;
#line 252 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		if (_tmp60_) {
#line 2146 "wizard-source.c"
			const gchar* _tmp61_ = NULL;
#line 253 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
			_tmp61_ = _ ("32-bit x86 system");
#line 253 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
			_tmp47_ = _tmp61_;
#line 2152 "wizard-source.c"
		} else {
			const gchar* _tmp62_ = NULL;
#line 254 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
			_tmp62_ = _ ("64-bit x86 system");
#line 254 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
			_tmp47_ = _tmp62_;
#line 2159 "wizard-source.c"
		}
#line 252 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_tmp63_ = _tmp47_;
#line 252 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_tmp64_ = g_strdup (_tmp63_);
#line 252 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		architecture = _tmp64_;
#line 255 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_tmp65_ = architecture;
#line 255 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_tmp66_ = (GtkLabel*) gtk_label_new (_tmp65_);
#line 255 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		g_object_ref_sink (_tmp66_);
#line 255 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_g_object_unref0 (label);
#line 255 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		label = _tmp66_;
#line 256 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_tmp67_ = label;
#line 256 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		gtk_label_set_ellipsize (_tmp67_, PANGO_ELLIPSIZE_END);
#line 257 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_tmp68_ = label;
#line 257 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_tmp69_ = gtk_widget_get_style_context ((GtkWidget*) _tmp68_);
#line 257 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		gtk_style_context_add_class (_tmp69_, "boxes-step-label");
#line 258 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_tmp70_ = label;
#line 258 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		g_object_set ((GtkMisc*) _tmp70_, "xalign", 0.0f, NULL);
#line 259 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_tmp71_ = vbox;
#line 259 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_tmp72_ = label;
#line 259 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		gtk_box_pack_start (_tmp71_, (GtkWidget*) _tmp72_, TRUE, TRUE, (guint) 0);
#line 261 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_tmp73_ = _data72_->media;
#line 261 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_tmp74_ = _tmp73_->os;
#line 261 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_tmp75_ = osinfo_product_get_vendor ((OsinfoProduct*) _tmp74_);
#line 261 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_tmp76_ = _tmp75_;
#line 261 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		if (_tmp76_ != NULL) {
#line 2207 "wizard-source.c"
			GtkLabel* _tmp77_ = NULL;
			GtkLabel* _tmp78_ = NULL;
			const gchar* _tmp79_ = NULL;
			const gchar* _tmp80_ = NULL;
			const gchar* _tmp81_ = NULL;
			BoxesInstallerMedia* _tmp82_ = NULL;
			OsinfoOs* _tmp83_ = NULL;
			const gchar* _tmp84_ = NULL;
			const gchar* _tmp85_ = NULL;
			gchar* _tmp86_ = NULL;
			gchar* _tmp87_ = NULL;
			gchar* _tmp88_ = NULL;
			gchar* _tmp89_ = NULL;
#line 263 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
			_tmp77_ = label;
#line 263 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
			_tmp78_ = label;
#line 263 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
			_tmp79_ = gtk_label_get_label (_tmp78_);
#line 263 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
			_tmp80_ = _tmp79_;
#line 263 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
			_tmp81_ = _ (" from %s");
#line 263 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
			_tmp82_ = _data72_->media;
#line 263 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
			_tmp83_ = _tmp82_->os;
#line 263 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
			_tmp84_ = osinfo_product_get_vendor ((OsinfoProduct*) _tmp83_);
#line 263 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
			_tmp85_ = _tmp84_;
#line 263 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
			_tmp86_ = g_strdup_printf (_tmp81_, _tmp85_);
#line 263 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
			_tmp87_ = _tmp86_;
#line 263 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
			_tmp88_ = g_strconcat (_tmp80_, _tmp87_, NULL);
#line 263 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
			_tmp89_ = _tmp88_;
#line 263 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
			gtk_label_set_label (_tmp78_, _tmp89_);
#line 263 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
			_g_free0 (_tmp89_);
#line 263 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
			_g_free0 (_tmp87_);
#line 2253 "wizard-source.c"
		}
#line 251 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_g_free0 (architecture);
#line 2257 "wizard-source.c"
	}
#line 266 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp90_ = self->priv->media_vbox;
#line 266 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	gtk_widget_show_all ((GtkWidget*) _tmp90_);
#line 267 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp91_ = self->priv->media_scrolled;
#line 267 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	gtk_widget_show ((GtkWidget*) _tmp91_);
#line 222 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (label);
#line 222 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_g_free0 (media_label);
#line 222 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (vbox);
#line 222 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (image);
#line 222 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (hbox);
#line 222 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	block72_data_unref (_data72_);
#line 222 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_data72_ = NULL;
#line 2281 "wizard-source.c"
}


static Block73Data* block73_data_ref (Block73Data* _data73_) {
#line 270 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	g_atomic_int_inc (&_data73_->_ref_count_);
#line 270 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	return _data73_;
#line 2290 "wizard-source.c"
}


static void block73_data_unref (void * _userdata_) {
	Block73Data* _data73_;
	_data73_ = (Block73Data*) _userdata_;
#line 270 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	if (g_atomic_int_dec_and_test (&_data73_->_ref_count_)) {
#line 2299 "wizard-source.c"
		BoxesWizardSource * self;
#line 270 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		self = _data73_->self;
#line 270 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		(_data73_->clicked_target_destroy_notify == NULL) ? NULL : (_data73_->clicked_target_destroy_notify (_data73_->clicked_target), NULL);
#line 270 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_data73_->clicked = NULL;
#line 270 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_data73_->clicked_target = NULL;
#line 270 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_data73_->clicked_target_destroy_notify = NULL;
#line 270 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_g_object_unref0 (self);
#line 270 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		g_slice_free (Block73Data, _data73_);
#line 2315 "wizard-source.c"
	}
}


static Block74Data* block74_data_ref (Block74Data* _data74_) {
#line 276 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	g_atomic_int_inc (&_data74_->_ref_count_);
#line 276 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	return _data74_;
#line 2325 "wizard-source.c"
}


static void block74_data_unref (void * _userdata_) {
	Block74Data* _data74_;
	_data74_ = (Block74Data*) _userdata_;
#line 276 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	if (g_atomic_int_dec_and_test (&_data74_->_ref_count_)) {
#line 2334 "wizard-source.c"
		BoxesWizardSource * self;
#line 276 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		self = _data74_->_data73_->self;
#line 276 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_g_object_unref0 (_data74_->button);
#line 276 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		block73_data_unref (_data74_->_data73_);
#line 276 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_data74_->_data73_ = NULL;
#line 276 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		g_slice_free (Block74Data, _data74_);
#line 2346 "wizard-source.c"
	}
}


static void ___lambda183_ (Block74Data* _data74_) {
	Block73Data* _data73_;
	BoxesWizardSource * self;
	ClickedFunc _tmp0_ = NULL;
	void* _tmp0__target = NULL;
	gboolean _tmp1_ = FALSE;
#line 278 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_data73_ = _data74_->_data73_;
#line 278 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	self = _data73_->self;
#line 279 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp0_ = _data73_->clicked;
#line 279 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp0__target = _data73_->clicked_target;
#line 279 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp1_ = _tmp0_ (_tmp0__target);
#line 279 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	if (_tmp1_) {
#line 2369 "wizard-source.c"
		GtkButton* _tmp2_ = NULL;
#line 280 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_tmp2_ = _data74_->button;
#line 280 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		boxes_wizard_source_set_selected (self, (GtkWidget*) _tmp2_);
#line 2375 "wizard-source.c"
	}
}


static void ____lambda183__gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 278 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	___lambda183_ (self);
#line 2383 "wizard-source.c"
}


static GtkBox* boxes_wizard_source_add_entry (BoxesWizardSource* self, GtkBox* box, ClickedFunc clicked, void* clicked_target, GDestroyNotify clicked_target_destroy_notify, gint h_margin, gint v_margin, const gchar* media) {
	GtkBox* result = NULL;
	Block73Data* _data73_;
	ClickedFunc _tmp0_ = NULL;
	void* _tmp0__target = NULL;
	GtkContainer* row = NULL;
	ClickedFunc _tmp1_ = NULL;
	void* _tmp1__target = NULL;
	GtkBox* hbox = NULL;
	GtkBox* _tmp10_ = NULL;
	GtkContainer* _tmp11_ = NULL;
	GtkBox* _tmp12_ = NULL;
	GtkContainer* _tmp13_ = NULL;
	GtkStyleContext* _tmp14_ = NULL;
	GtkBox* _tmp15_ = NULL;
	GtkContainer* _tmp16_ = NULL;
	const gchar* _tmp17_ = NULL;
	GtkBox* _tmp21_ = NULL;
	GtkBox* _tmp22_ = NULL;
	gint _tmp23_ = 0;
	GtkBox* _tmp24_ = NULL;
	GtkBox* _tmp25_ = NULL;
	gint _tmp26_ = 0;
#line 270 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 270 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	g_return_val_if_fail (box != NULL, NULL);
#line 270 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_data73_ = g_slice_new0 (Block73Data);
#line 270 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_data73_->_ref_count_ = 1;
#line 270 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_data73_->self = g_object_ref (self);
#line 270 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp0_ = clicked;
#line 270 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp0__target = clicked_target;
#line 270 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	(_data73_->clicked_target_destroy_notify == NULL) ? NULL : (_data73_->clicked_target_destroy_notify (_data73_->clicked_target), NULL);
#line 270 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_data73_->clicked = NULL;
#line 270 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_data73_->clicked_target = NULL;
#line 270 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_data73_->clicked_target_destroy_notify = NULL;
#line 270 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_data73_->clicked = _tmp0_;
#line 270 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_data73_->clicked_target = _tmp0__target;
#line 270 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_data73_->clicked_target_destroy_notify = clicked_target_destroy_notify;
#line 276 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp1_ = _data73_->clicked;
#line 276 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp1__target = _data73_->clicked_target;
#line 276 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	if (_tmp1_ != NULL) {
#line 2444 "wizard-source.c"
		Block74Data* _data74_;
		GtkButton* _tmp2_ = NULL;
		GtkButton* _tmp3_ = NULL;
		GtkButton* _tmp4_ = NULL;
		GtkContainer* _tmp5_ = NULL;
#line 276 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_data74_ = g_slice_new0 (Block74Data);
#line 276 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_data74_->_ref_count_ = 1;
#line 276 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_data74_->_data73_ = block73_data_ref (_data73_);
#line 277 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_tmp2_ = (GtkButton*) gtk_button_new ();
#line 277 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		g_object_ref_sink (_tmp2_);
#line 277 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_data74_->button = _tmp2_;
#line 278 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_tmp3_ = _data74_->button;
#line 278 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		g_signal_connect_data (_tmp3_, "clicked", (GCallback) ____lambda183__gtk_button_clicked, block74_data_ref (_data74_), (GClosureNotify) block74_data_unref, 0);
#line 282 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_tmp4_ = _data74_->button;
#line 282 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_tmp5_ = _g_object_ref0 ((GtkContainer*) _tmp4_);
#line 282 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_g_object_unref0 (row);
#line 282 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		row = _tmp5_;
#line 276 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		block74_data_unref (_data74_);
#line 276 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_data74_ = NULL;
#line 2478 "wizard-source.c"
	} else {
		GtkAlignment* bin = NULL;
		GtkAlignment* _tmp6_ = NULL;
		GtkAlignment* _tmp7_ = NULL;
		GtkAlignment* _tmp8_ = NULL;
		GtkContainer* _tmp9_ = NULL;
#line 284 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_tmp6_ = (GtkAlignment*) gtk_alignment_new ((gfloat) 0, (gfloat) 0, (gfloat) 1, (gfloat) 1);
#line 284 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		g_object_ref_sink (_tmp6_);
#line 284 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		bin = _tmp6_;
#line 285 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_tmp7_ = bin;
#line 285 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		boxes_draw_as_css_box ((GtkWidget*) _tmp7_);
#line 286 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_tmp8_ = bin;
#line 286 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_tmp9_ = _g_object_ref0 ((GtkContainer*) _tmp8_);
#line 286 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_g_object_unref0 (row);
#line 286 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		row = _tmp9_;
#line 276 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_g_object_unref0 (bin);
#line 2505 "wizard-source.c"
	}
#line 288 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp10_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 20);
#line 288 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	g_object_ref_sink (_tmp10_);
#line 288 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	hbox = _tmp10_;
#line 289 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp11_ = row;
#line 289 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp12_ = hbox;
#line 289 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	gtk_container_add (_tmp11_, (GtkWidget*) _tmp12_);
#line 290 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp13_ = row;
#line 290 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp14_ = gtk_widget_get_style_context ((GtkWidget*) _tmp13_);
#line 290 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	gtk_style_context_add_class (_tmp14_, "boxes-menu-row");
#line 292 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp15_ = box;
#line 292 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp16_ = row;
#line 292 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	gtk_container_add ((GtkContainer*) _tmp15_, (GtkWidget*) _tmp16_);
#line 293 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp17_ = media;
#line 293 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	if (_tmp17_ != NULL) {
#line 2535 "wizard-source.c"
		GtkContainer* _tmp18_ = NULL;
		const gchar* _tmp19_ = NULL;
		gchar* _tmp20_ = NULL;
#line 294 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_tmp18_ = row;
#line 294 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_tmp19_ = media;
#line 294 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_tmp20_ = g_strdup (_tmp19_);
#line 294 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		g_object_set_data_full ((GObject*) _tmp18_, "boxes-media", _tmp20_, g_free);
#line 2547 "wizard-source.c"
	}
#line 296 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp21_ = hbox;
#line 296 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp22_ = hbox;
#line 296 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp23_ = h_margin;
#line 296 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	gtk_widget_set_margin_right ((GtkWidget*) _tmp22_, _tmp23_);
#line 296 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	gtk_widget_set_margin_left ((GtkWidget*) _tmp21_, _tmp23_);
#line 297 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp24_ = hbox;
#line 297 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp25_ = hbox;
#line 297 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp26_ = v_margin;
#line 297 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	gtk_widget_set_margin_bottom ((GtkWidget*) _tmp25_, _tmp26_);
#line 297 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	gtk_widget_set_margin_top ((GtkWidget*) _tmp24_, _tmp26_);
#line 299 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	result = hbox;
#line 299 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (row);
#line 299 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	block73_data_unref (_data73_);
#line 299 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_data73_ = NULL;
#line 299 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	return result;
#line 2579 "wizard-source.c"
}


static gboolean boxes_wizard_source_launch_file_selection_dialog (BoxesWizardSource* self) {
	gboolean result = FALSE;
	GtkFileChooserDialog* dialog = NULL;
	const gchar* _tmp0_ = NULL;
	BoxesApp* _tmp1_ = NULL;
	GtkApplicationWindow* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
	const gchar* _tmp4_ = NULL;
	GtkFileChooserDialog* _tmp5_ = NULL;
	GtkFileChooserDialog* _tmp6_ = NULL;
	GtkFileChooserDialog* _tmp7_ = NULL;
	GtkFileFilter* _tmp8_ = NULL;
	GtkFileFilter* _tmp9_ = NULL;
	GtkFileChooserDialog* _tmp10_ = NULL;
	GtkFileFilter* _tmp11_ = NULL;
	GtkFileFilter* _tmp12_ = NULL;
	gboolean ret = FALSE;
	GtkFileChooserDialog* _tmp19_ = NULL;
	gint _tmp20_ = 0;
	GtkFileChooserDialog* _tmp25_ = NULL;
#line 302 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 303 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp0_ = _ ("Select a device or ISO file");
#line 303 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp1_ = boxes_app_app;
#line 303 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp2_ = _tmp1_->window;
#line 303 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp3_ = _ ("_Cancel");
#line 303 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp4_ = _ ("_Open");
#line 303 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp5_ = (GtkFileChooserDialog*) gtk_file_chooser_dialog_new (_tmp0_, (GtkWindow*) _tmp2_, GTK_FILE_CHOOSER_ACTION_OPEN, _tmp3_, GTK_RESPONSE_CANCEL, _tmp4_, GTK_RESPONSE_ACCEPT, NULL);
#line 303 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	g_object_ref_sink (_tmp5_);
#line 303 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	dialog = _tmp5_;
#line 308 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp6_ = dialog;
#line 308 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	gtk_file_chooser_set_show_hidden ((GtkFileChooser*) _tmp6_, FALSE);
#line 309 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp7_ = dialog;
#line 309 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp8_ = gtk_file_filter_new ();
#line 309 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	g_object_ref_sink (_tmp8_);
#line 309 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp9_ = _tmp8_;
#line 309 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	gtk_file_chooser_set_filter ((GtkFileChooser*) _tmp7_, _tmp9_);
#line 309 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (_tmp9_);
#line 310 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp10_ = dialog;
#line 310 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp11_ = gtk_file_chooser_get_filter ((GtkFileChooser*) _tmp10_);
#line 310 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp12_ = _tmp11_;
#line 310 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	gtk_file_filter_add_mime_type (_tmp12_, "application/x-cd-image");
#line 2645 "wizard-source.c"
	{
		const gchar** extension_collection = NULL;
		gint extension_collection_length1 = 0;
		gint _extension_collection_size_ = 0;
		gint extension_it = 0;
#line 311 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		extension_collection = BOXES_INSTALLED_MEDIA_supported_extensions;
#line 311 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		extension_collection_length1 = G_N_ELEMENTS (BOXES_INSTALLED_MEDIA_supported_extensions);
#line 311 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		for (extension_it = 0; extension_it < G_N_ELEMENTS (BOXES_INSTALLED_MEDIA_supported_extensions); extension_it = extension_it + 1) {
#line 2657 "wizard-source.c"
			const gchar* extension = NULL;
#line 311 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
			extension = extension_collection[extension_it];
#line 2661 "wizard-source.c"
			{
				GtkFileChooserDialog* _tmp13_ = NULL;
				GtkFileFilter* _tmp14_ = NULL;
				GtkFileFilter* _tmp15_ = NULL;
				const gchar* _tmp16_ = NULL;
				gchar* _tmp17_ = NULL;
				gchar* _tmp18_ = NULL;
#line 312 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
				_tmp13_ = dialog;
#line 312 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
				_tmp14_ = gtk_file_chooser_get_filter ((GtkFileChooser*) _tmp13_);
#line 312 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
				_tmp15_ = _tmp14_;
#line 312 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
				_tmp16_ = extension;
#line 312 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
				_tmp17_ = g_strconcat ("*", _tmp16_, NULL);
#line 312 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
				_tmp18_ = _tmp17_;
#line 312 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
				gtk_file_filter_add_pattern (_tmp15_, _tmp18_);
#line 312 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
				_g_free0 (_tmp18_);
#line 2685 "wizard-source.c"
			}
		}
	}
#line 313 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	ret = FALSE;
#line 314 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp19_ = dialog;
#line 314 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp20_ = gtk_dialog_run ((GtkDialog*) _tmp19_);
#line 314 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	if (_tmp20_ == ((gint) GTK_RESPONSE_ACCEPT)) {
#line 2697 "wizard-source.c"
		GtkFileChooserDialog* _tmp21_ = NULL;
		gchar* _tmp22_ = NULL;
		gchar* _tmp23_ = NULL;
		GtkEntry* _tmp24_ = NULL;
#line 315 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_tmp21_ = dialog;
#line 315 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_tmp22_ = gtk_file_chooser_get_uri ((GtkFileChooser*) _tmp21_);
#line 315 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_tmp23_ = _tmp22_;
#line 315 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		boxes_wizard_source_set_uri (self, _tmp23_);
#line 315 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_g_free0 (_tmp23_);
#line 317 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		boxes_wizard_source_set_install_media (self, NULL);
#line 318 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_tmp24_ = self->url_entry;
#line 318 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		g_signal_emit_by_name (_tmp24_, "activate");
#line 320 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		ret = TRUE;
#line 2720 "wizard-source.c"
	}
#line 323 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp25_ = dialog;
#line 323 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	gtk_widget_destroy ((GtkWidget*) _tmp25_);
#line 325 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	result = ret;
#line 325 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (dialog);
#line 325 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	return result;
#line 2732 "wizard-source.c"
}


static void boxes_wizard_source_on_media_selected (BoxesWizardSource* self, BoxesInstallerMedia* media) {
	GError * _inner_error_ = NULL;
#line 328 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	g_return_if_fail (self != NULL);
#line 328 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	g_return_if_fail (media != NULL);
#line 2742 "wizard-source.c"
	{
		BoxesInstallerMedia* _tmp0_ = NULL;
		BoxesMediaManager* _tmp1_ = NULL;
		BoxesInstallerMedia* _tmp2_ = NULL;
		BoxesInstallerMedia* _tmp3_ = NULL;
		BoxesInstallerMedia* _tmp4_ = NULL;
		BoxesInstallerMedia* _tmp5_ = NULL;
		const gchar* _tmp6_ = NULL;
		GtkEntry* _tmp7_ = NULL;
#line 330 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_tmp1_ = self->priv->media_manager;
#line 330 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_tmp2_ = media;
#line 330 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_tmp3_ = boxes_media_manager_create_installer_media_from_media (_tmp1_, _tmp2_, &_inner_error_);
#line 330 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_tmp0_ = _tmp3_;
#line 330 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		if (_inner_error_ != NULL) {
#line 2762 "wizard-source.c"
			goto __catch103_g_error;
		}
#line 330 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_tmp4_ = _tmp0_;
#line 330 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		boxes_wizard_source_set_install_media (self, _tmp4_);
#line 330 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_g_object_unref0 (_tmp4_);
#line 331 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_tmp5_ = media;
#line 331 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_tmp6_ = _tmp5_->device_file;
#line 331 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		boxes_wizard_source_set_uri (self, _tmp6_);
#line 332 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_tmp7_ = self->url_entry;
#line 332 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		g_signal_emit_by_name (_tmp7_, "activate");
#line 2781 "wizard-source.c"
	}
	goto __finally103;
	__catch103_g_error:
	{
		GError* _error_ = NULL;
		BoxesInstallerMedia* _tmp8_ = NULL;
		const gchar* _tmp9_ = NULL;
		GError* _tmp10_ = NULL;
		const gchar* _tmp11_ = NULL;
#line 329 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_error_ = _inner_error_;
#line 329 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_inner_error_ = NULL;
#line 335 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_tmp8_ = media;
#line 335 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_tmp9_ = _tmp8_->device_file;
#line 335 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_tmp10_ = _error_;
#line 335 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_tmp11_ = _tmp10_->message;
#line 335 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		g_warning ("wizard-source.vala:335: Failed to setup installation media '%s': %s", _tmp9_, _tmp11_);
#line 329 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_g_error_free0 (_error_);
#line 2807 "wizard-source.c"
	}
	__finally103:
#line 329 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	if (_inner_error_ != NULL) {
#line 329 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 329 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		g_clear_error (&_inner_error_);
#line 329 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		return;
#line 2818 "wizard-source.c"
	}
}


GtkWidget* boxes_wizard_source_get_widget (BoxesWizardSource* self) {
	GtkWidget* result;
	GtkNotebook* _tmp0_ = NULL;
#line 53 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 53 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp0_ = self->priv->notebook;
#line 53 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	result = (GtkWidget*) _tmp0_;
#line 53 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	return result;
#line 2834 "wizard-source.c"
}


GtkWidget* boxes_wizard_source_get_selected (BoxesWizardSource* self) {
	GtkWidget* result;
	GtkWidget* _tmp0_ = NULL;
#line 54 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 54 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp0_ = self->priv->_selected;
#line 54 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	result = _tmp0_;
#line 54 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	return result;
#line 2849 "wizard-source.c"
}


void boxes_wizard_source_set_selected (BoxesWizardSource* self, GtkWidget* value) {
	GtkWidget* _tmp0_ = NULL;
	GtkWidget* _tmp1_ = NULL;
#line 54 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	g_return_if_fail (self != NULL);
#line 54 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp0_ = value;
#line 54 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 54 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (self->priv->_selected);
#line 54 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	self->priv->_selected = _tmp1_;
#line 54 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	g_object_notify ((GObject *) self, "selected");
#line 2868 "wizard-source.c"
}


BoxesSourcePage boxes_wizard_source_get_page (BoxesWizardSource* self) {
	BoxesSourcePage result;
	BoxesSourcePage _tmp0_ = 0;
#line 57 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	g_return_val_if_fail (self != NULL, 0);
#line 57 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp0_ = self->priv->_page;
#line 57 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	result = _tmp0_;
#line 57 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	return result;
#line 2883 "wizard-source.c"
}


void boxes_wizard_source_set_page (BoxesWizardSource* self, BoxesSourcePage value) {
	BoxesSourcePage _tmp0_ = 0;
	GtkNotebook* _tmp1_ = NULL;
	BoxesSourcePage _tmp2_ = 0;
	BoxesSourcePage _tmp3_ = 0;
	GtkWidget* _tmp4_ = NULL;
	BoxesSourcePage _tmp6_ = 0;
	BoxesSourcePage _tmp7_ = 0;
#line 58 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	g_return_if_fail (self != NULL);
#line 59 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp0_ = value;
#line 59 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	self->priv->_page = _tmp0_;
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp1_ = self->priv->notebook;
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp2_ = boxes_wizard_source_get_page (self);
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp3_ = _tmp2_;
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	gtk_notebook_set_current_page (_tmp1_, (gint) _tmp3_);
#line 61 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp4_ = self->priv->_selected;
#line 61 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	if (_tmp4_ != NULL) {
#line 2913 "wizard-source.c"
		GtkWidget* _tmp5_ = NULL;
#line 62 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_tmp5_ = self->priv->_selected;
#line 62 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		gtk_widget_grab_focus (_tmp5_);
#line 2919 "wizard-source.c"
	}
#line 63 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp6_ = boxes_wizard_source_get_page (self);
#line 63 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp7_ = _tmp6_;
#line 63 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	switch (_tmp7_) {
#line 63 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		case BOXES_SOURCE_PAGE_MAIN:
#line 2929 "wizard-source.c"
		{
			GtkBox* _tmp8_ = NULL;
#line 65 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
			boxes_wizard_source_add_media_entries (self, NULL, NULL);
#line 67 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
			_tmp8_ = self->priv->main_vbox;
#line 67 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
			gtk_widget_grab_focus ((GtkWidget*) _tmp8_);
#line 68 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
			break;
#line 2940 "wizard-source.c"
		}
#line 63 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		case BOXES_SOURCE_PAGE_URL:
#line 2944 "wizard-source.c"
		{
			GtkEntry* _tmp9_ = NULL;
			GtkEntry* _tmp10_ = NULL;
#line 70 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
			_tmp9_ = self->url_entry;
#line 70 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
			g_signal_emit_by_name ((GtkEditable*) _tmp9_, "changed");
#line 71 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
			_tmp10_ = self->url_entry;
#line 71 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
			gtk_widget_grab_focus ((GtkWidget*) _tmp10_);
#line 72 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
			break;
#line 2958 "wizard-source.c"
		}
		default:
#line 63 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		break;
#line 2963 "wizard-source.c"
	}
#line 58 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	g_object_notify ((GObject *) self, "page");
#line 2967 "wizard-source.c"
}


const gchar* boxes_wizard_source_get_uri (BoxesWizardSource* self) {
	const gchar* result;
	GtkEntry* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
#line 77 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 77 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp0_ = self->url_entry;
#line 77 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp1_ = gtk_entry_get_text (_tmp0_);
#line 77 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	result = _tmp1_;
#line 77 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	return result;
#line 2985 "wizard-source.c"
}


void boxes_wizard_source_set_uri (BoxesWizardSource* self, const gchar* value) {
	GtkEntry* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
#line 78 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	g_return_if_fail (self != NULL);
#line 78 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp0_ = self->url_entry;
#line 78 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp1_ = value;
#line 78 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	gtk_entry_set_text (_tmp0_, _tmp1_);
#line 78 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	g_object_notify ((GObject *) self, "uri");
#line 3002 "wizard-source.c"
}


BoxesInstallerMedia* boxes_wizard_source_get_install_media (BoxesWizardSource* self) {
	BoxesInstallerMedia* result;
	BoxesInstallerMedia* _tmp0_ = NULL;
#line 80 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 80 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp0_ = self->priv->_install_media;
#line 80 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	result = _tmp0_;
#line 80 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	return result;
#line 3017 "wizard-source.c"
}


static void boxes_wizard_source_set_install_media (BoxesWizardSource* self, BoxesInstallerMedia* value) {
	BoxesInstallerMedia* _tmp0_ = NULL;
	BoxesInstallerMedia* _tmp1_ = NULL;
#line 80 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	g_return_if_fail (self != NULL);
#line 80 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp0_ = value;
#line 80 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 80 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (self->priv->_install_media);
#line 80 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	self->priv->_install_media = _tmp1_;
#line 80 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	g_object_notify ((GObject *) self, "install-media");
#line 3036 "wizard-source.c"
}


static void boxes_wizard_source_class_init (BoxesWizardSourceClass * klass) {
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	boxes_wizard_source_parent_class = g_type_class_peek_parent (klass);
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	g_type_class_add_private (klass, sizeof (BoxesWizardSourcePrivate));
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_boxes_wizard_source_get_property;
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_boxes_wizard_source_set_property;
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_wizard_source_finalize;
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_WIZARD_SOURCE_WIDGET, g_param_spec_object ("widget", "widget", "widget", GTK_TYPE_WIDGET, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_WIZARD_SOURCE_SELECTED, g_param_spec_object ("selected", "selected", "selected", GTK_TYPE_WIDGET, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_WIZARD_SOURCE_PAGE, g_param_spec_enum ("page", "page", "page", BOXES_TYPE_SOURCE_PAGE, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_WIZARD_SOURCE_URI, g_param_spec_string ("uri", "uri", "uri", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_WIZARD_SOURCE_INSTALL_MEDIA, g_param_spec_object ("install-media", "install-media", "install-media", BOXES_TYPE_INSTALLER_MEDIA, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 3061 "wizard-source.c"
}


static void boxes_wizard_source_instance_init (BoxesWizardSource * self) {
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	self->priv = BOXES_WIZARD_SOURCE_GET_PRIVATE (self);
#line 3068 "wizard-source.c"
}


static void boxes_wizard_source_finalize (GObject* obj) {
	BoxesWizardSource * self;
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_WIZARD_SOURCE, BoxesWizardSource);
#line 54 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (self->priv->_selected);
#line 80 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (self->priv->_install_media);
#line 82 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (self->priv->main_vbox);
#line 83 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (self->priv->media_vbox);
#line 84 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (self->priv->media_scrolled);
#line 85 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (self->priv->notebook);
#line 86 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (self->priv->url_label);
#line 87 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (self->priv->url_image);
#line 88 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (self->url_entry);
#line 90 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (self->priv->media_manager);
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	G_OBJECT_CLASS (boxes_wizard_source_parent_class)->finalize (obj);
#line 3098 "wizard-source.c"
}


GType boxes_wizard_source_get_type (void) {
	static volatile gsize boxes_wizard_source_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_wizard_source_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesWizardSourceClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_wizard_source_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesWizardSource), 0, (GInstanceInitFunc) boxes_wizard_source_instance_init, NULL };
		GType boxes_wizard_source_type_id;
		boxes_wizard_source_type_id = g_type_register_static (G_TYPE_OBJECT, "BoxesWizardSource", &g_define_type_info, 0);
		g_once_init_leave (&boxes_wizard_source_type_id__volatile, boxes_wizard_source_type_id);
	}
	return boxes_wizard_source_type_id__volatile;
}


static void _vala_boxes_wizard_source_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	BoxesWizardSource * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_WIZARD_SOURCE, BoxesWizardSource);
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	switch (property_id) {
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		case BOXES_WIZARD_SOURCE_WIDGET:
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		g_value_set_object (value, boxes_wizard_source_get_widget (self));
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		break;
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		case BOXES_WIZARD_SOURCE_SELECTED:
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		g_value_set_object (value, boxes_wizard_source_get_selected (self));
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		break;
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		case BOXES_WIZARD_SOURCE_PAGE:
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		g_value_set_enum (value, boxes_wizard_source_get_page (self));
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		break;
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		case BOXES_WIZARD_SOURCE_URI:
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		g_value_set_string (value, boxes_wizard_source_get_uri (self));
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		break;
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		case BOXES_WIZARD_SOURCE_INSTALL_MEDIA:
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		g_value_set_object (value, boxes_wizard_source_get_install_media (self));
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		break;
#line 3149 "wizard-source.c"
		default:
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		break;
#line 3155 "wizard-source.c"
	}
}


static void _vala_boxes_wizard_source_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	BoxesWizardSource * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_WIZARD_SOURCE, BoxesWizardSource);
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	switch (property_id) {
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		case BOXES_WIZARD_SOURCE_SELECTED:
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		boxes_wizard_source_set_selected (self, g_value_get_object (value));
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		break;
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		case BOXES_WIZARD_SOURCE_PAGE:
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		boxes_wizard_source_set_page (self, g_value_get_enum (value));
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		break;
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		case BOXES_WIZARD_SOURCE_URI:
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		boxes_wizard_source_set_uri (self, g_value_get_string (value));
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		break;
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		case BOXES_WIZARD_SOURCE_INSTALL_MEDIA:
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		boxes_wizard_source_set_install_media (self, g_value_get_object (value));
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		break;
#line 3189 "wizard-source.c"
		default:
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		break;
#line 3195 "wizard-source.c"
	}
}



